@@ -4,8 +4,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Alpha_wrap_3/include/CGAL/Alpha_wrap_3/internal/Triangle_soup_oracle.h $
-// $Id: Triangle_soup_oracle.h 7a8f91b 2022-11-01T16:09:26+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Alpha_wrap_3/include/CGAL/Alpha_wrap_3/internal/Triangle_soup_oracle.h $
+// $Id: include/CGAL/Alpha_wrap_3/internal/Triangle_soup_oracle.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Mael Rouxel-Labbé
@@ -19,8 +19,8 @@
 #include <CGAL/Alpha_wrap_3/internal/Oracle_base.h>
 #include <CGAL/Alpha_wrap_3/internal/splitting_helper.h>
 
-#include <CGAL/AABB_triangle_primitive.h>
-#include <CGAL/AABB_traits.h>
+#include <CGAL/AABB_triangle_primitive_3.h>
+#include <CGAL/AABB_traits_3.h>
 #include <CGAL/AABB_tree.h>
 #include <CGAL/boost/graph/named_params_helper.h>
 #include <CGAL/Named_function_parameters.h>
@@ -134,7 +134,7 @@ public:
     if(points.empty() || faces.empty())
     {
 #ifdef CGAL_AW3_DEBUG
-      Rcpp::Rcout << "Warning: Input is empty " << std::endl;
+      Rcpp::Rcout << "Warning: Input is empty (TS)" << std::endl;
 #endif
       return;
     }
@@ -144,7 +144,7 @@ public:
 #endif
 
     PPM pm = choose_parameter<PPM>(get_parameter(np, internal_np::point_map));
-    CGAL_static_assertion((std::is_same<typename boost::property_traits<PPM>::value_type, Point_3>::value));
+    static_assert(std::is_same<typename boost::property_traits<PPM>::value_type, Point_3>::value);
 
     Splitter_base::reserve(faces.size());
 
@@ -165,11 +165,22 @@ public:
 
       const Triangle_3 tr = triangle(p0, p1, p2);
       if(is_degenerate(tr))
+      {
+#ifdef CGAL_AW3_DEBUG
+        Rcpp::Rcerr << "Warning: ignoring degenerate face " << tr << std::endl;
+#endif
         continue;
+      }
 
       Splitter_base::split_and_insert_datum(tr, this->tree(), this->geom_traits());
     }
 
+    // Manually constructing it here purely for profiling reasons: if we keep the lazy approach,
+    // it will be done at the first treatment of a facet that needs a Steiner point.
+    // So if one wanted to bench the flood fill runtime, it would be skewed by the time it takes
+    // to accelerate the tree.
+    this->tree().accelerate_distance_queries();
+
 #ifdef CGAL_AW3_DEBUG
     Rcpp::Rcout << "Tree: " << this->tree().size() << " primitives (" << faces.size() << " faces in input)" << std::endl;
 #endif
@@ -180,12 +191,31 @@ public:
   void add_triangle_soup(const TriangleRange& triangles,
                          const CGAL_NP_CLASS& /*np*/ = CGAL::parameters::default_values())
   {
+    if(triangles.empty())
+    {
+#ifdef CGAL_AW3_DEBUG
+      Rcpp::Rcout << "Warning: Input is empty (TS)" << std::endl;
+#endif
+      return;
+    }
+
+#ifdef CGAL_AW3_DEBUG
+    Rcpp::Rcout << "Insert into AABB Tree (triangles)..." << std::endl;
+#endif
+
     typename Geom_traits::Is_degenerate_3 is_degenerate = this->geom_traits().is_degenerate_3_object();
 
+    Splitter_base::reserve(triangles.size());
+
     for(const Triangle_3& tr : triangles)
     {
       if(is_degenerate(tr))
+      {
+#ifdef CGAL_AW3_DEBUG
+        Rcpp::Rcerr << "Warning: ignoring degenerate triangle " << tr << std::endl;
+#endif
         continue;
+      }
 
       Splitter_base::split_and_insert_datum(tr, this->tree(), this->geom_traits());
     }
