@@ -4,8 +4,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Arrangement_on_surface_2/include/CGAL/Arr_point_location/Td_dag_node.h $
-// $Id: Td_dag_node.h 014c06f 2022-11-14T15:32:47+01:00 albert-github
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Arrangement_on_surface_2/include/CGAL/Arr_point_location/Td_dag_node.h $
+// $Id: include/CGAL/Arr_point_location/Td_dag_node.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Michal Balas <balasmic@post.tau.ac.il>
@@ -29,7 +29,7 @@
 #include <list>
 #include <functional>
 
-#include <boost/variant.hpp>
+#include <variant>
 
 namespace CGAL {
 
@@ -113,7 +113,7 @@ protected:
 
   public:
 
-    class clear_neighbors_visitor : public boost::static_visitor< void  >
+    class clear_neighbors_visitor
     {
     public:
       void operator()(Td_active_trapezoid& t) const
@@ -143,7 +143,7 @@ protected:
     //d'tor
     ~Node()
     {
-      boost::apply_visitor(clear_neighbors_visitor(), m_data);
+      std::visit(clear_neighbors_visitor(), m_data);
     }
 
     bool is_inner_node() const //MICHAL: a node with only left child (like removed node) will be considered as a leaf
