@@ -4,8 +4,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Arrangement_on_surface_2/include/CGAL/Arr_polycurve_traits_2.h $
-// $Id: Arr_polycurve_traits_2.h 014c06f 2022-11-14T15:32:47+01:00 albert-github
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Arrangement_on_surface_2/include/CGAL/Arr_polycurve_traits_2.h $
+// $Id: include/CGAL/Arr_polycurve_traits_2.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s): Efi Fogel <efif@post.tau.ac.il>
@@ -28,7 +28,7 @@
 #include <iterator>
 #include <type_traits>
 
-#include <boost/variant.hpp>
+#include <variant>
 
 #include <CGAL/basic.h>
 #include <CGAL/tags.h>
@@ -186,9 +186,9 @@ public:
     OutputIterator operator_impl(const Curve_2& cv, OutputIterator oi,
                                  Arr_all_sides_oblivious_tag) const
     {
-      typedef boost::variant<Point_2, X_monotone_subcurve_2>
+      typedef std::variant<Point_2, X_monotone_subcurve_2>
         Make_x_monotone_subresult;
-      typedef boost::variant<Point_2, X_monotone_curve_2>
+      typedef std::variant<Point_2, X_monotone_curve_2>
         Make_x_monotone_result;
 
       // If the polycurve is empty, return.
@@ -213,7 +213,7 @@ public:
       for (auto its = cv.subcurves_begin(); its != cv.subcurves_end(); ++its)
         make_seg_x_monotone(*its, std::back_inserter(x_seg_objects));
       auto it = x_seg_objects.begin();
-      const auto* x_seg_p = boost::get<X_monotone_subcurve_2>(&(*it));
+      const auto* x_seg_p = std::get_if<X_monotone_subcurve_2>(&(*it));
 #if ! defined (CGAL_NO_ASSERTIONS)
       CGAL_assertion(x_seg_p != nullptr);
 #endif
@@ -261,7 +261,7 @@ public:
 #endif
 
       for (++it; it != x_seg_objects.end(); ++it) {
-        const auto* x_seg_p = boost::get<X_monotone_subcurve_2>(&(*it));
+        const auto* x_seg_p = std::get_if<X_monotone_subcurve_2>(&(*it));
 #if ! defined (CGAL_NO_ASSERTIONS)
         CGAL_assertion(x_seg_p != nullptr);
 #endif
@@ -319,9 +319,9 @@ public:
     OutputIterator operator_impl(const Curve_2& cv, OutputIterator oi,
                                  Arr_not_all_sides_oblivious_tag) const
     {
-      typedef boost::variant<Point_2, X_monotone_subcurve_2>
+      typedef std::variant<Point_2, X_monotone_subcurve_2>
         Make_x_monotone_subresult;
-      typedef boost::variant<Point_2, X_monotone_curve_2>
+      typedef std::variant<Point_2, X_monotone_curve_2>
         Make_x_monotone_result;
 
       // If the polycurve is empty, return.
@@ -351,7 +351,7 @@ public:
       for (auto its = cv.subcurves_begin(); its != cv.subcurves_end(); ++its)
         make_seg_x_monotone(*its, std::back_inserter(x_seg_objects));
       auto it = x_seg_objects.begin();
-      const auto* x_seg_p = boost::get<X_monotone_subcurve_2>(&(*it));
+      const auto* x_seg_p = std::get_if<X_monotone_subcurve_2>(&(*it));
 #if ! defined (CGAL_NO_ASSERTIONS)
       CGAL_assertion(x_seg_p != nullptr);
 #endif
@@ -399,7 +399,7 @@ public:
 #endif
 
       for (++it; it != x_seg_objects.end(); ++it) {
-        const auto* x_seg_p = boost::get<X_monotone_subcurve_2>(&(*it));
+        const auto* x_seg_p = std::get_if<X_monotone_subcurve_2>(&(*it));
 #if ! defined (CGAL_NO_ASSERTIONS)
         CGAL_assertion(x_seg_p != nullptr);
 #endif
@@ -592,8 +592,7 @@ public:
       Comparison_result dir = cmp_seg_endpts(xcv[0]);
 
       // Locate the subcurve on the polycurve xcv that contains p.
-      std::size_t i = m_poly_traits.locate(xcv, p);
-
+      auto i = m_poly_traits.locate_impl(xcv, p, All_sides_oblivious_category());
       CGAL_precondition(i != Polycurve_traits_2::INVALID_INDEX);
 
       // Clear the output curves.
@@ -697,10 +696,9 @@ public:
                OutputIterator oi) const
     {
       typedef std::pair<Point_2, Multiplicity>        Intersection_point;
-      typedef boost::variant<Intersection_point, X_monotone_subcurve_2>
+      typedef std::variant<Intersection_point, X_monotone_subcurve_2>
                                                       Intersection_base_result;
-      typedef boost::variant<Intersection_point, X_monotone_curve_2>
-                                                      Intersection_result;
+
 
       const Subcurve_traits_2* geom_traits = m_poly_traits.subcurve_traits_2();
       auto cmp_y_at_x = m_poly_traits.compare_y_at_x_2_object();
@@ -745,7 +743,7 @@ public:
             // cv1's right endpoint equals cv2's left endpoint
             // Thus we can return this single(!) intersection point
             Intersection_point p(max_vertex(cv1[i1]), 0);
-            *oi++ = Intersection_result(p);
+            *oi++ = p;
             return oi;
           }
           dir1 == SMALLER ?
@@ -768,7 +766,7 @@ public:
             // cv2's right endpoint equals cv1's left endpoint
             // Thus we can return this single(!) intersection point
             Intersection_point p(max_vertex(cv2[i2]), 0);
-            *oi++ = Intersection_result(p);
+            *oi++ = p;
             return oi;
           }
 
@@ -825,7 +823,7 @@ public:
           intersect(cv1[i1], cv2[i2], std::back_inserter(xections));
           for (const auto& xection : xections) {
             const X_monotone_subcurve_2* subcv_p =
-              boost::get<X_monotone_subcurve_2>(&xection);
+              std::get_if<X_monotone_subcurve_2>(&xection);
             if (subcv_p != nullptr) {
               ocv.push_back(*subcv_p);
               oi = output_ocv (ocv, invert_ocv, oi);
@@ -833,8 +831,8 @@ public:
             }
 
             const Intersection_point* p_p =
-              boost::get<Intersection_point>(&xection);
-            if (p_p != nullptr) *oi++ = Intersection_result(*p_p);
+              std::get_if<Intersection_point>(&xection);
+            if (p_p != nullptr) *oi++ = *p_p;
           }
         }
         else if (right_coincides && left_coincides) {
@@ -847,7 +845,7 @@ public:
 
           for (const auto& item : sub_xections) {
             const X_monotone_subcurve_2* x_seg =
-              boost::get<X_monotone_subcurve_2>(&item);
+              std::get_if<X_monotone_subcurve_2>(&item);
             if (x_seg != nullptr) {
               X_monotone_subcurve_2 seg = *x_seg;
               // We maintain the variant that if the input curves have opposite
@@ -864,7 +862,7 @@ public:
             }
 
             const Intersection_point* p_ptr =
-              boost::get<Intersection_point>(&item);
+              std::get_if<Intersection_point>(&item);
             if (p_ptr != nullptr) {
               // Any point that is not equal to the max_vertex of the
               // subcurve should be inserted into oi.
@@ -872,7 +870,7 @@ public:
               // will be taken care of as the min_vertex of in the next
               // iteration.
               if (! equal(p_ptr->first, max_vertex(cv1[i1])))
-                *oi++ = Intersection_result(*p_ptr);
+                *oi++ = *p_ptr;
             }
           }
         }
@@ -897,11 +895,11 @@ public:
             // it multiplicity 0.
             if (left_res == SMALLER) {
               Intersection_point p(min_vertex(cv2[i2]), 0);
-              *oi++ = Intersection_result(p);
+              *oi++ = p;
             }
             else {
               Intersection_point p(min_vertex(cv1[i1]), 0);
-              *oi++ = Intersection_result(p);
+              *oi++ = p;
             }
           }
         }
@@ -942,7 +940,7 @@ public:
             (i1 != Polycurve_traits_2::INVALID_INDEX) ?
             return_point(max_vertex(cv1[i1+1]), 0) :
             return_point(max_vertex(cv1[0]), 0);
-          *oi++ = Intersection_result(ip);
+          *oi++ = ip;
         }
         else if (right_res == LARGER) {
           ip = (dir2 == SMALLER) ?
@@ -950,7 +948,7 @@ public:
             (i2 != Polycurve_traits_2::INVALID_INDEX) ?
             return_point(max_vertex(cv2[i2+1]), 0) :
             return_point(max_vertex(cv2[0]), 0);
-          *oi++ = Intersection_result(ip);
+          *oi++ = ip;
         }
         else if (((i1 > 0) && (dir1 == SMALLER)) ||
                  ((i1 < n1) && (dir1 != SMALLER)) ||
@@ -962,7 +960,7 @@ public:
             (i1 != Polycurve_traits_2::INVALID_INDEX) ?
             return_point(max_vertex(cv1[i1+1]), 0) :
             return_point(max_vertex(cv1[0]), 0);
-          *oi++ = Intersection_result(ip);
+          *oi++ = ip;
         }
         else {
           CGAL_assertion_msg((dir2 == SMALLER && i2 > 0) ||
@@ -977,7 +975,7 @@ public:
             (i2 != Polycurve_traits_2::INVALID_INDEX) ?
             return_point(max_vertex(cv2[i2+1]), 0) :
             return_point(max_vertex(cv2[0]), 0);
-          *oi++ = Intersection_result(ip);
+          *oi++ = ip;
         }
       }
 
@@ -990,15 +988,12 @@ public:
     inline OutputIterator output_ocv
     (std::vector<X_monotone_subcurve_2>& ocv, bool invert_ocv, OutputIterator oi) const
     {
-      typedef std::pair<Point_2, Multiplicity>        Intersection_point;
-      typedef boost::variant<Intersection_point, X_monotone_curve_2>
-                                                      Intersection_result;
       X_monotone_curve_2 curve;
       if (invert_ocv)
         std::reverse (ocv.begin(), ocv.end());
       for (X_monotone_subcurve_2& sc : ocv)
         curve.push_back (sc);
-      *(oi ++) = Intersection_result(curve);
+      *(oi ++) = curve;
 
       ocv.clear();
 
