@@ -7,8 +7,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Kernel_23/include/CGAL/Bbox_2.h $
-// $Id: Bbox_2.h 529add2 2021-07-07T14:37:41+02:00 Laurent Rineau
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Kernel_23/include/CGAL/Bbox_2.h $
+// $Id: include/CGAL/Bbox_2.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Andreas Fabri
@@ -71,6 +71,7 @@ public:
   inline Bbox_2&     operator+=(const Bbox_2 &b);
 
   inline void dilate(int dist);
+  inline void scale(double factor);
 };
 
 inline
@@ -170,6 +171,25 @@ Bbox_2::dilate(int dist)
   rep[3] = float_advance(rep[3],dist);
 }
 
+inline
+void
+Bbox_2::scale(double factor)
+{
+  CGAL_precondition(factor > 0);
+
+  if(factor == 1.)
+    return;
+
+  std::array<double, 2> half_width = { (xmax() - xmin()) * 0.5,
+                                       (ymax() - ymin()) * 0.5 };
+  std::array<double, 2> center = { xmin() + half_width[0],
+                                   ymin() + half_width[1] };
+  rep[0] = center[0] - factor * half_width[0];
+  rep[1] = center[1] - factor * half_width[1];
+  rep[2] = center[0] + factor * half_width[0];
+  rep[3] = center[1] + factor * half_width[1];
+}
+
 inline
 bool
 do_overlap(const Bbox_2 &bb1, const Bbox_2 &bb2)
