@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Boolean_set_operations_2/include/CGAL/Boolean_set_operations_2/Gps_simplifier_traits.h $
-// $Id: Gps_simplifier_traits.h 6fcbee1 2020-04-21T17:12:21+03:00 Efi Fogel
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Boolean_set_operations_2/include/CGAL/Boolean_set_operations_2/Gps_simplifier_traits.h $
+// $Id: include/CGAL/Boolean_set_operations_2/Gps_simplifier_traits.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -133,11 +133,8 @@ public:
     {
       typedef const std::pair<Base_point_2, Multiplicity>
         Intersection_base_point;
-      typedef boost::variant<Intersection_base_point, Base_x_monotone_curve_2>
+      typedef std::variant<Intersection_base_point, Base_x_monotone_curve_2>
                                                         Intersection_base_result;
-      typedef const std::pair<Point_2, Multiplicity>    Intersection_point;
-      typedef boost::variant<Intersection_point, X_monotone_curve_2>
-                                                        Intersection_result;
 
       const auto* base_traits = m_traits.m_base_traits;
       auto base_cmp_xy = base_traits->compare_xy_2_object();
@@ -170,17 +167,17 @@ public:
       // the extenede X_monotone_curve_2
       for (const auto& xection : xections) {
         const Intersection_base_point* base_pt =
-          boost::get<Intersection_base_point>(&xection);
+          std::get_if<Intersection_base_point>(&xection);
         if (base_pt != nullptr) {
           Point_data pt_data(m_traits.invalid_index());
           Point_2 point_plus(base_pt->first, pt_data); // the extended point
           *oi++ =
-            Intersection_result(std::make_pair(point_plus, base_pt->second));
+            std::make_pair(point_plus, base_pt->second);
           continue;
         }
 
         const Base_x_monotone_curve_2* overlap_cv =
-          boost::get<Base_x_monotone_curve_2>(&xection);
+          std::get_if<Base_x_monotone_curve_2>(&xection);
 
         CGAL_assertion(overlap_cv != nullptr);
         unsigned int ov_bc;
@@ -202,7 +199,7 @@ public:
         }
 
         Curve_data cv_data(ov_bc, ov_twin_bc, m_traits.invalid_index());
-        *oi++ = Intersection_result(X_monotone_curve_2(*overlap_cv, cv_data));
+        *oi++ = X_monotone_curve_2(*overlap_cv, cv_data);
       }
 
       return oi;
