@@ -4,8 +4,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Linear_cell_complex/include/CGAL/CMap_linear_cell_complex_storages_with_index.h $
-// $Id: CMap_linear_cell_complex_storages_with_index.h 804f288 2023-03-10T13:31:56+01:00 Guillaume Damiand
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Linear_cell_complex/include/CGAL/CMap_linear_cell_complex_storages_with_index.h $
+// $Id: include/CGAL/CMap_linear_cell_complex_storages_with_index.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Guillaume Damiand <guillaume.damiand@liris.cnrs.fr>
@@ -86,7 +86,7 @@ namespace CGAL {
     struct Container_for_attributes : public
         Compact_container_with_index<T,
         typename Allocator_traits::template rebind_alloc<T>,
-        Multiply_by_two_policy_for_cc_with_size<64>, size_type >
+        Multiply_by_two_policy_for_cc_with_size<64>, Index_type >
     {};
     /// Typedef for attributes
     typedef typename internal::template Get_attributes_tuple<Dart_wrapper>::type
@@ -100,14 +100,14 @@ namespace CGAL {
     {};
     template<int i>
     struct Attribute_const_descriptor:
-        public Helper::template Attribute_const_descriptor<i>
+      public Helper::template Attribute_const_descriptor<i>
     {};
     template<int i>
     struct Attribute_range: public Helper::template Attribute_range<i>
     {};
     template<int i>
     struct Attribute_const_range:
-        public Helper::template Attribute_const_range<i>
+      public Helper::template Attribute_const_range<i>
     {};
 
     typedef typename Attribute_type<0>::type Vertex_attribute;
@@ -170,6 +170,10 @@ namespace CGAL {
       { return mmap.mdarts.is_used(i); }
       bool owns(size_type i) const
       { return mmap.mdarts.owns(i); }
+      size_type capacity() const
+      { return mmap.mdarts.capacity(); }
+      size_type upper_bound() const
+      { return mmap.mdarts.upper_bound(); }
     private:
       Self & mmap;
     };
@@ -203,7 +207,7 @@ namespace CGAL {
      *  @return true iff the map is empty.
      */
     bool is_empty() const
-    { return  darts().empty(); }
+    { return darts().empty(); }
 
     /// @return the number of darts.
     size_type number_of_darts() const
@@ -288,19 +292,19 @@ namespace CGAL {
     template<unsigned int i>
     typename Attribute_descriptor<i>::type attribute(Dart_descriptor ADart)
     {
-      CGAL_static_assertion_msg(Helper::template Dimension_index<i>::value>=0,
-                        "attribute<i> called but i-attributes are disabled.");
+      static_assert(Helper::template Dimension_index<i>::value>=0,
+                     "attribute<i> called but i-attributes are disabled.");
       return std::get<Helper::template Dimension_index<i>::value>
-          (mdarts[ADart].mattribute_descriptors);
+        (mdarts[ADart].mattribute_descriptors);
     }
     template<unsigned int i>
     typename Attribute_const_descriptor<i>::type
     attribute(Dart_const_descriptor ADart) const
     {
-      CGAL_static_assertion_msg(Helper::template Dimension_index<i>::value>=0,
-                        "attribute<i> called but i-attributes are disabled.");
+      static_assert(Helper::template Dimension_index<i>::value>=0,
+                     "attribute<i> called but i-attributes are disabled.");
       return std::get<Helper::template Dimension_index<i>::value>
-          (mdarts[ADart].mattribute_descriptors);
+        (mdarts[ADart].mattribute_descriptors);
     }
 
     // Copy a given attribute
@@ -308,7 +312,7 @@ namespace CGAL {
     typename Attribute_descriptor<i>::type copy_attribute
     (typename Attribute_const_descriptor<i>::type ah)
     {
-      CGAL_static_assertion_msg(Helper::template Dimension_index<i>::value>=0,
+      static_assert(Helper::template Dimension_index<i>::value>=0,
                      "copy_attribute<i> called but i-attributes are disabled.");
       // We need to do a reserve before the emplace in order to avoid a bug of
       // invalid reference when the container is reallocated.
@@ -361,7 +365,7 @@ namespace CGAL {
     {
       CGAL_assertion( ah!=null_descriptor );
       return std::get<Helper::template Dimension_index<i>::value>
-          (mattribute_containers)[ah];
+        (mattribute_containers)[ah];
     }
     template<unsigned int i>
     const typename Attribute_type<i>::type&
@@ -369,7 +373,7 @@ namespace CGAL {
     {
       CGAL_assertion( ah!=null_descriptor );
       return std::get<Helper::template Dimension_index<i>::value>
-          (mattribute_containers)[ah];
+        (mattribute_containers)[ah];
     }
 
     // Get the dart of the given attribute
@@ -487,14 +491,14 @@ namespace CGAL {
                                   typename Attribute_descriptor<i>::type ah)
     {
       std::get<Helper::template Dimension_index<i>::value>
-          (mdarts[dh].mattribute_descriptors) = ah;
+        (mdarts[dh].mattribute_descriptors) = ah;
     }
 
     /** Link a dart with a given dart for a given dimension.
-       * @param adart the dart to link.
-       * @param adart2 the dart to link with.
-       * @param i the dimension.
-       */
+     * @param adart the dart to link.
+     * @param adart2 the dart to link with.
+     * @param i the dimension.
+     */
     template<unsigned int i>
     void dart_link_beta(Dart_descriptor adart, Dart_descriptor adart2)
     {
@@ -510,9 +514,9 @@ namespace CGAL {
     }
 
     /** Unlink a dart for a given dimension.
-       * @param adart a dart.
-       * @param i the dimension.
-       */
+     * @param adart a dart.
+     * @param i the dimension.
+     */
     template<unsigned int i>
     void dart_unlink_beta(Dart_descriptor adart)
     {
