@@ -3,13 +3,13 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Circular_kernel_2/include/CGAL/Circular_kernel_2/Intersection_traits.h $
-// $Id: Intersection_traits.h 0779373 2020-03-26T13:31:46+01:00 Sébastien Loriot
-// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Circular_kernel_2/include/CGAL/Circular_kernel_2/Intersection_traits.h $
+// $Id: include/CGAL/Circular_kernel_2/Intersection_traits.h 50cfbde3b84 $
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Circular_kernel_2/include/CGAL/Circular_kernel_2/Intersection_traits.h $
-// $Id: Intersection_traits.h 0779373 2020-03-26T13:31:46+01:00 Sébastien Loriot
-// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Circular_kernel_2/include/CGAL/Circular_kernel_2/Intersection_traits.h $
+// $Id: include/CGAL/Circular_kernel_2/Intersection_traits.h 50cfbde3b84 $
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
 // Author(s)     : Philipp Möller and Sebastien Loriot
@@ -17,9 +17,12 @@
 #ifndef CGAL_CIRCULAR_KERNEL_2_INTERSECTION_TRAITS_H
 #define CGAL_CIRCULAR_KERNEL_2_INTERSECTION_TRAITS_H
 
+#include <CGAL/license/Circular_kernel_2.h>
+
+
 #include <CGAL/Intersection_traits.h>
 
-#include <boost/variant.hpp>
+#include <variant>
 
 namespace CGAL {
 
@@ -40,7 +43,7 @@ template<typename CK>
 struct CK2_Intersection_traits<CK, typename CK::Circle_2, typename CK::Circle_2>
 {
   typedef typename
-  boost::variant< typename CK::Circle_2,
+  std::variant< typename CK::Circle_2,
                   typename std::pair< typename CK::Circular_arc_point_2,
                                       unsigned int >
                   CGAL_ADDITIONAL_VARIANT_FOR_ICL
@@ -52,7 +55,7 @@ template<typename CK>
 struct CK2_Intersection_traits<CK, typename CK::Circular_arc_2, typename CK::Circular_arc_2>
 {
   typedef typename
-  boost::variant< typename CK::Circular_arc_2,
+  std::variant< typename CK::Circular_arc_2,
                   typename std::pair< typename CK::Circular_arc_point_2,
                                       unsigned int >
                   CGAL_ADDITIONAL_VARIANT_FOR_ICL
@@ -64,7 +67,7 @@ template<typename CK>
 struct CK2_Intersection_traits<CK, typename CK::Line_arc_2, typename CK::Line_arc_2>
 {
   typedef typename
-  boost::variant< typename CK::Line_arc_2,
+  std::variant< typename CK::Line_arc_2,
                   typename std::pair< typename CK::Circular_arc_point_2,
                                       unsigned int >
                   CGAL_ADDITIONAL_VARIANT_FOR_ICL
@@ -76,7 +79,7 @@ template<typename CK>
 struct CK2_Intersection_traits<CK, typename CK::Line_arc_2, typename CK::Circle_2>
 {
   typedef typename
-  boost::variant< typename std::pair< typename CK::Circular_arc_point_2,
+  std::variant< typename std::pair< typename CK::Circular_arc_point_2,
                                       unsigned int >
                   CGAL_ADDITIONAL_VARIANT_FOR_ICL
                   >
@@ -92,7 +95,7 @@ template<typename CK>
 struct CK2_Intersection_traits<CK, typename CK::Line_arc_2, typename CK::Circular_arc_2>
 {
   typedef typename
-  boost::variant< typename std::pair< typename CK::Circular_arc_point_2,
+  std::variant< typename std::pair< typename CK::Circular_arc_point_2,
                                       unsigned int >
                   CGAL_ADDITIONAL_VARIANT_FOR_ICL
                   >
@@ -108,7 +111,7 @@ template<typename CK>
 struct CK2_Intersection_traits<CK, typename CK::Line_arc_2, typename CK::Line_2>
 {
   typedef typename
-  boost::variant< typename CK::Line_arc_2,
+  std::variant< typename CK::Line_arc_2,
                   typename std::pair< typename CK::Circular_arc_point_2,
                                       unsigned int >
                   CGAL_ADDITIONAL_VARIANT_FOR_ICL
@@ -125,7 +128,7 @@ template<typename CK>
 struct CK2_Intersection_traits<CK, typename CK::Line_2, typename CK::Circular_arc_2>
 {
   typedef typename
-  boost::variant< typename std::pair< typename CK::Circular_arc_point_2,
+  std::variant< typename std::pair< typename CK::Circular_arc_point_2,
                                       unsigned int >
                   CGAL_ADDITIONAL_VARIANT_FOR_ICL
                   >
@@ -155,7 +158,7 @@ template<typename CK>
 struct CK2_Intersection_traits<CK, typename CK::Line_2, typename CK::Circle_2>
 {
   typedef typename
-  boost::variant< typename std::pair< typename CK::Circular_arc_point_2,
+  std::variant< typename std::pair< typename CK::Circular_arc_point_2,
                                       unsigned int >
                   CGAL_ADDITIONAL_VARIANT_FOR_ICL
                   >
