@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Convex_hull_3/include/CGAL/Convex_hull_traits_3.h $
-// $Id: Convex_hull_traits_3.h 61d42c3 2021-12-16T13:49:45+01:00 Mael Rouxel-Labbé
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Convex_hull_3/include/CGAL/Convex_hull_traits_3.h $
+// $Id: include/CGAL/Convex_hull_traits_3.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -151,7 +151,7 @@ struct GT3_for_CH3 {
   template <class R_, class Polyhedron = Default,
             class Has_filtered_predicates_tag = Boolean_tag
             <
-              boost::is_floating_point<typename R_::FT>::type::value &&
+              std::is_floating_point<typename R_::FT>::type::value &&
               R_::Has_filtered_predicates_tag::value
             > >
 class Convex_hull_traits_3
