@@ -4,9 +4,9 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Arrangement_on_surface_2/include/CGAL/Curved_kernel_via_analysis_2/gfx/Curve_renderer_2.h $
-// $Id: Curve_renderer_2.h 384377e 2023-01-17T10:02:22+01:00 Sebastien Loriot
-// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Arrangement_on_surface_2/include/CGAL/Curved_kernel_via_analysis_2/gfx/Curve_renderer_2.h $
+// $Id: include/CGAL/Curved_kernel_via_analysis_2/gfx/Curve_renderer_2.h 50cfbde3b84 $
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Pavel Emeliyanenko <asm@mpi-sb.mpg.de>
 //
@@ -20,6 +20,9 @@
 #ifndef CGAL_CKVA_CURVE_RENDERER_2_H
 #define CGAL_CKVA_CURVE_RENDERER_2_H
 
+#include <CGAL/license/Arrangement_on_surface_2.h>
+
+
 #ifndef CGAL_AK_ENABLE_DEPRECATED_INTERFACE
 #define CGAL_AK_ENABLE_DEPRECATED_INTERFACE 1
 #endif
@@ -219,7 +222,7 @@ private:
     //! returns \c true when the precision limit for a specified number type is
     //! reached
     typename Renderer_traits::Precision_limit limit;
-    //! maximum level of subdivision dependending on specified number type
+    //! maximum level of subdivision depending on specified number type
     static const unsigned MAX_SUBDIVISION_LEVEL =
             Renderer_traits::MAX_SUBDIVISION_LEVEL;
 
@@ -424,8 +427,8 @@ template < class Coord_2, template < class, class > class Container,
         class Allocator >
 void draw(const Arc_2& arc,
           Container< std::vector< Coord_2 >, Allocator >& points,
-          boost::optional< Coord_2 > *end_pt1 = nullptr,
-          boost::optional< Coord_2 > *end_pt2 = nullptr) {
+          std::optional< Coord_2 > *end_pt1 = nullptr,
+          std::optional< Coord_2 > *end_pt2 = nullptr) {
 
 #ifdef CGAL_CKVA_CR_TIMING
     refine_timer.start();
@@ -863,7 +866,7 @@ void draw(const Arc_2& arc,
             get_pixel_coords(l, y_clip, pix_beg);
             get_pixel_coords(ptmp->left, it->second ? engine.y_max_r :
                 engine.y_min_r, pix_end);
-            if(CGAL_ABS(ptmp->left - l) <= engine.pixel_w_r*2) {
+            if(CGAL_ABS(Rational(ptmp->left - l)) <= engine.pixel_w_r*2) {
 
                 Coordinate_2 xy(Coordinate_1(pt), *support, arc.arcno());
                 Rational _;
