@@ -8,8 +8,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Kernel_23/include/CGAL/Direction_2.h $
-// $Id: Direction_2.h 5872413 2022-06-10T08:48:53+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Kernel_23/include/CGAL/Direction_2.h $
+// $Id: include/CGAL/Direction_2.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -39,7 +39,7 @@ class Direction_2 : public R_::Kernel_base::Direction_2
   typedef typename R_::Kernel_base::Direction_2      RDirection_2;
 
   typedef Direction_2                        Self;
-  CGAL_static_assertion((std::is_same<Self, typename R_::Direction_2>::value));
+  static_assert(std::is_same<Self, typename R_::Direction_2>::value);
 
 public:
 
