@@ -2,8 +2,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Solver_interface/include/CGAL/Eigen_matrix.h $
-// $Id: Eigen_matrix.h b5c21e1 2022-11-23T18:48:43+01:00 Mael Rouxel-Labbé
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Solver_interface/include/CGAL/Eigen_matrix.h $
+// $Id: include/CGAL/Eigen_matrix.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Gael Guennebaud
@@ -25,7 +25,7 @@ namespace CGAL {
 The class `Eigen_matrix` is a wrapper around `Eigen` matrix type
 <a href="https://eigen.tuxfamily.org/dox/classEigen_1_1Matrix.html">`Eigen::Matrix`</a>.
 
-\cgalModels `SvdTraits::Matrix`
+\cgalModels{SvdTraits::Matrix}
 
 \tparam T Number type.
 \tparam D1 Number of rows, or Dynamic
