@@ -4,8 +4,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Envelope_3/include/CGAL/Env_tracing_traits_3.h $
-// $Id: Env_tracing_traits_3.h 0779373 2020-03-26T13:31:46+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Envelope_3/include/CGAL/Env_tracing_traits_3.h $
+// $Id: include/CGAL/Env_tracing_traits_3.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -195,14 +195,15 @@ public:
       Base base;
       Rcpp::Rcerr << "Construct_projected_boundary_2: JUST FIRST" << std::endl;
       Rcpp::Rcerr << "Surface: " << s << std::endl;
-      std::list<CGAL::Object> l;
+      // TODO UPDATE CONCEPT + CHANGES.md
+      std::list< std::variant<std::pair<X_monotone_curve_2, Oriented_side>, Point_2 > > l;
       base.construct_projected_boundary_2_object() (s, std::back_inserter(l));
 
       if (l.size() > 0)
       {
-        std::pair<X_monotone_curve_2, CGAL::Oriented_side> i;
-        if (CGAL::assign(i, l.front()))
-          Rcpp::Rcerr << "First: " << i.first << std::endl;
+        if (const std::pair<X_monotone_curve_2, CGAL::Oriented_side>* i =
+            std::get_if<std::pair<X_monotone_curve_2, CGAL::Oriented_side>>(&l.front()))
+          Rcpp::Rcerr << "First: " << i->first << std::endl;
         else
           Rcpp::Rcerr << "First intersection is a point" << std::endl;
       }
@@ -233,15 +234,14 @@ public:
                 << std::endl;
       Rcpp::Rcerr << "Surface1: " << s1 << std::endl;
       Rcpp::Rcerr << "Surface2: " << s2 << std::endl;
-      std::list<CGAL::Object> l;
+      std::list< std::variant<Intersection_curve, Point_2 > > l;
       base.construct_projected_intersections_2_object() (s1, s2,
                                                          std::back_inserter(l));
 
       if (l.size() > 0)
       {
-        Intersection_curve i;
-        if (CGAL::assign(i, l.front()))
-          Rcpp::Rcerr << "First: " << i.first << std::endl;
+        if (const Intersection_curve* i = std::get_if<Intersection_curve>(&l.front()))
+          Rcpp::Rcerr << "First: " << i->first << std::endl;
         else
           Rcpp::Rcerr << "First intersection is not a point" << std::endl;
       }
