@@ -7,8 +7,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6/Number_types/include/CGAL/Exact_rational.h $
-// $Id: Exact_rational.h e46196d 2023-07-12T13:40:24+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Number_types/include/CGAL/Exact_rational.h $
+// $Id: include/CGAL/Exact_rational.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -30,10 +30,7 @@ It is a typedef of another number type. Its exact definition depends on
 the availability the third-party libraries \gmp, \core, and \leda. \cgal must
 be configured with at least one of those libraries.
 
-\cgalModels `Field`
-\cgalModels `RealEmbeddable`
-\cgalModels `Fraction`
-\cgalModels `FromDoubleConstructible`
+\cgalModels{Field,RealEmbeddable,Fraction,FromDoubleConstructible}
 
 */
 #if DOXYGEN_RUNNING
