@@ -4,8 +4,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Linear_cell_complex/include/CGAL/GMap_linear_cell_complex_storages.h $
-// $Id: GMap_linear_cell_complex_storages.h 4547818 2022-11-15T13:39:40+01:00 albert-github
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Linear_cell_complex/include/CGAL/GMap_linear_cell_complex_storages.h $
+// $Id: include/CGAL/GMap_linear_cell_complex_storages.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Guillaume Damiand <guillaume.damiand@liris.cnrs.fr>
@@ -75,7 +75,7 @@ namespace CGAL {
     typedef typename Dart_container::size_type             size_type;
 
     typedef std::nullptr_t Null_descriptor_type;
-    CGAL_CPP17_INLINE static constexpr Null_descriptor_type null_descriptor=nullptr;
+    inline static constexpr Null_descriptor_type null_descriptor=nullptr;
 
     using Type_for_compact_container=void*;
 
@@ -129,7 +129,7 @@ namespace CGAL {
     using Vertex_attribute_handle=Vertex_attribute_descriptor;
     using Vertex_attribute_const_handle=Vertex_attribute_const_descriptor;
 
-    CGAL_CPP17_INLINE static constexpr Null_descriptor_type null_handle=null_descriptor;
+    inline static constexpr Null_descriptor_type null_handle=null_descriptor;
 
     /// Number of marks
     static const size_type NB_MARKS = 32;
@@ -251,7 +251,7 @@ namespace CGAL {
     template<unsigned int i>
     typename Attribute_descriptor<i>::type attribute(Dart_descriptor ADart)
     {
-      CGAL_static_assertion_msg(Helper::template Dimension_index<i>::value>=0,
+      static_assert(Helper::template Dimension_index<i>::value>=0,
                      "attribute<i> called but i-attributes are disabled.");
       return std::get<Helper::template Dimension_index<i>::value>
         (ADart->mattribute_descriptors);
@@ -260,7 +260,7 @@ namespace CGAL {
     typename Attribute_const_descriptor<i>::type
     attribute(Dart_const_descriptor ADart) const
     {
-      CGAL_static_assertion_msg(Helper::template Dimension_index<i>::value>=0,
+      static_assert(Helper::template Dimension_index<i>::value>=0,
                      "attribute<i> called but i-attributes are disabled.");
       return std::get<Helper::template Dimension_index<i>::value>
         (ADart->mattribute_descriptors);
@@ -271,7 +271,7 @@ namespace CGAL {
     typename Attribute_descriptor<i>::type copy_attribute
     (typename Attribute_const_descriptor<i>::type ah)
     {
-      CGAL_static_assertion_msg(Helper::template Dimension_index<i>::value>=0,
+      static_assert(Helper::template Dimension_index<i>::value>=0,
                      "copy_attribute<i> called but i-attributes are disabled.");
       typename Attribute_descriptor<i>::type res=
         std::get<Helper::template Dimension_index<i>::value>
@@ -494,18 +494,6 @@ namespace CGAL {
     typename Helper::Attribute_containers mattribute_containers;
   };
 
-#ifndef CGAL_CXX17
-  template<unsigned int d_, unsigned int ambient_dim,
-           class Traits_, class Items_, class Alloc_>
-  constexpr typename GMap_linear_cell_complex_storage_1<d_, ambient_dim, Traits_, Items_, Alloc_>::Null_descriptor_type
-  GMap_linear_cell_complex_storage_1<d_, ambient_dim, Traits_, Items_, Alloc_>::null_descriptor;
-
-  template<unsigned int d_, unsigned int ambient_dim,
-           class Traits_, class Items_, class Alloc_>
-  constexpr typename GMap_linear_cell_complex_storage_1<d_, ambient_dim, Traits_, Items_, Alloc_>::Null_descriptor_type
-  GMap_linear_cell_complex_storage_1<d_, ambient_dim, Traits_, Items_, Alloc_>::null_handle;
-#endif
-
 } // namespace CGAL
 
 #if defined(BOOST_GCC)
