@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/STL_Extension/include/CGAL/Handle_with_policy.h $
-// $Id: Handle_with_policy.h eed54a0 2022-11-15T18:45:39+01:00 albert-github
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/STL_Extension/include/CGAL/Handle_with_policy.h $
+// $Id: include/CGAL/Handle_with_policy.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Michael Seel <seel@mpi-inf.mpg.de>
@@ -21,8 +21,6 @@
 #include <CGAL/assertions.h>
 #include <CGAL/use.h>
 
-#include <boost/mpl/if.hpp>
-
 #include <cstddef>
 
 #ifdef CGAL_USE_LEDA
@@ -355,8 +353,8 @@ namespace Intern {
             typedef ::CGAL::Reference_counted_hierarchy_with_union<Alloc>
                 Reference_counted_hierarchy_with_union;
             CGAL_USE_TYPE(Reference_counted_hierarchy_with_union);
-            CGAL_static_assertion((
-              ::CGAL::is_same_or_derived< Reference_counted_hierarchy_with_union, T >::value ));
+            static_assert(
+              ::CGAL::is_same_or_derived< Reference_counted_hierarchy_with_union, T >::value );
         }
         typedef T Rep;
     };
@@ -599,7 +597,7 @@ public:
         typedef Reference_counted_hierarchy_with_union<Alloc> Type;
     };
 
-    // abbreviation to re-use its implementation below.
+    // abbreviation to reuse its implementation below.
     typedef Handle_policy_union U;
 
     /*! \brief unifies the representations of the two handles \a h and \a g.
@@ -728,10 +726,10 @@ public:
     static Bind bind;
 
     // Define type that is used for function matching
-    typedef typename ::boost::mpl::if_c<
+    typedef std::conditional_t<
          is_class_hierarchy,
            ::CGAL::Tag_true,
-           ::CGAL::Tag_false >::type
+           ::CGAL::Tag_false >
          Class_hierarchy;
 
     //! the internal representation, i.e., \c T plus a reference count
@@ -760,7 +758,7 @@ private:
     static Rep_allocator allocator;
 
     static Rep* new_rep( const Rep& rep) {
-        CGAL_static_assertion( !(
+        static_assert( !(
            ::CGAL::is_same_or_derived< Reference_counted_hierarchy_base, Handled_type >::value ));
         Rep* p = allocator.allocate(1);
         std::allocator_traits<Rep_allocator>::construct(allocator, p, rep);
@@ -855,8 +853,8 @@ protected:
     //! argument, and the single argument template constructor no other
     //! constructor will work for class hierarchies of representations.
     Handle_with_policy( Rep* p) : ptr_( p) {
-        CGAL_static_assertion((
-           ::CGAL::is_same_or_derived< Reference_counted_hierarchy_base, Handled_type >::value ));
+        static_assert(
+           ::CGAL::is_same_or_derived< Reference_counted_hierarchy_base, Handled_type >::value );
         //Bind bind_; // trigger compile-time check
         //(void)bind_;
         (void)Bind();
@@ -869,8 +867,8 @@ protected:
     //! version of \c initialize_with is applicable in this case except
     //! the template version with one argument.
     void initialize_with( Rep* p) {
-        CGAL_static_assertion((
-           ::CGAL::is_same_or_derived< Reference_counted_hierarchy_base, Handled_type >::value ));
+        static_assert(
+           ::CGAL::is_same_or_derived< Reference_counted_hierarchy_base, Handled_type >::value );
         //Bind bind_; // trigger compile-time check
         //(void)bind_;
         (void)Bind();
