@@ -7,8 +7,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Homogeneous_kernel/include/CGAL/Homogeneous/PointH2.h $
-// $Id: PointH2.h 4f5f834 2022-06-10T07:37:53+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Homogeneous_kernel/include/CGAL/Homogeneous/PointH2.h $
+// $Id: include/CGAL/Homogeneous/PointH2.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -18,7 +18,6 @@
 #define CGAL_HOMOGENEOUS_POINT_2_H
 
 #include <CGAL/Origin.h>
-#include <boost/type_traits/is_convertible.hpp>
 #include <boost/mpl/and.hpp>
 #include <boost/mpl/logical.hpp>
 
@@ -54,8 +53,8 @@ public:
 
     template < typename Tx, typename Ty >
     PointH2(const Tx & x, const Ty & y,
-            std::enable_if_t< boost::mpl::and_<boost::is_convertible<Tx, RT>,
-                                               boost::is_convertible<Ty, RT> >::value >* = 0)
+            std::enable_if_t< std::is_convertible_v<Tx, RT> &&
+                              std::is_convertible_v<Ty, RT> >* = 0)
       : base(x, y) {}
 
     PointH2(const FT& x, const FT& y)
