@@ -4,8 +4,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Point_set_processing_3/include/CGAL/IO/write_las_points.h $
-// $Id: write_las_points.h eed54a0 2022-11-15T18:45:39+01:00 albert-github
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Point_set_processing_3/include/CGAL/IO/write_las_points.h $
+// $Id: include/CGAL/IO/write_las_points.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s) : Simon Giraudot
@@ -38,7 +38,7 @@
 #  pragma GCC diagnostic ignored "-Wstrict-aliasing"
 #endif
 
-#define USE_AS_DLL
+#define USE_AS_DLL 1
 #include <lasdefinitions.hpp>
 #include <lasreader_las.hpp>
 #include <laswriter_las.hpp>
@@ -85,41 +85,41 @@ make_las_point_writer(PointMap point_map)
 namespace internal {
 namespace LAS {
 
-  inline void output_value(LASpoint& r, const unsigned short& v, LAS_property::Intensity&)
+  inline void output_value(LASpoint& r, const unsigned short& v, const LAS_property::Intensity&)
   { r.set_intensity(v); }
-  inline void output_value(LASpoint& r, const unsigned char& v, LAS_property::Return_number&)
+  inline void output_value(LASpoint& r, const unsigned char& v, const LAS_property::Return_number&)
   { r.set_return_number(v); }
-  inline void output_value(LASpoint& r, const unsigned char& v, LAS_property::Number_of_returns&)
+  inline void output_value(LASpoint& r, const unsigned char& v, const LAS_property::Number_of_returns&)
   { r.set_number_of_returns(v); }
-  inline void output_value(LASpoint& r, const unsigned char& v, LAS_property::Scan_direction_flag&)
+  inline void output_value(LASpoint& r, const unsigned char& v, const LAS_property::Scan_direction_flag&)
   { r.set_scan_direction_flag(v); }
-  inline void output_value(LASpoint& r, const unsigned char& v, LAS_property::Edge_of_flight_line&)
+  inline void output_value(LASpoint& r, const unsigned char& v, const LAS_property::Edge_of_flight_line&)
   { r.set_edge_of_flight_line(v); }
-  inline void output_value(LASpoint& r, const unsigned char& v, LAS_property::Classification&)
+  inline void output_value(LASpoint& r, const unsigned char& v, const LAS_property::Classification&)
   { r.set_classification(v); }
-  inline void output_value(LASpoint& r, const unsigned char& v, LAS_property::Synthetic_flag&)
+  inline void output_value(LASpoint& r, const unsigned char& v, const LAS_property::Synthetic_flag&)
   { r.set_synthetic_flag(v); }
-  inline void output_value(LASpoint& r, const unsigned char& v, LAS_property::Keypoint_flag&)
+  inline void output_value(LASpoint& r, const unsigned char& v, const LAS_property::Keypoint_flag&)
   { r.set_keypoint_flag(v); }
-  inline void output_value(LASpoint& r, const unsigned char& v, LAS_property::Withheld_flag&)
+  inline void output_value(LASpoint& r, const unsigned char& v, const LAS_property::Withheld_flag&)
   { r.set_withheld_flag(v); }
-  inline void output_value(LASpoint& r, const float& v, LAS_property::Scan_angle&)
+  inline void output_value(LASpoint& r, const float& v, const LAS_property::Scan_angle&)
   { r.set_scan_angle_rank(char(v)); }
-  inline void output_value(LASpoint& r, const unsigned char& v, LAS_property::User_data&)
+  inline void output_value(LASpoint& r, const unsigned char& v, const LAS_property::User_data&)
   { r.set_user_data(v); }
-  inline void output_value(LASpoint& r, const unsigned short& v, LAS_property::Point_source_ID&)
+  inline void output_value(LASpoint& r, const unsigned short& v, const LAS_property::Point_source_ID&)
   { r.set_point_source_ID(v); }
-  inline void output_value(LASpoint& r, const unsigned int& v, LAS_property::Deleted_flag&)
+  inline void output_value(LASpoint& r, const unsigned int& v, const LAS_property::Deleted_flag&)
   { r.set_deleted_flag(v); }
-  inline void output_value(LASpoint& r, const double& v, LAS_property::GPS_time&)
+  inline void output_value(LASpoint& r, const double& v, const LAS_property::GPS_time&)
   { r.set_gps_time(v); }
-  inline void output_value(LASpoint& r, const unsigned short& v, LAS_property::R&)
+  inline void output_value(LASpoint& r, const unsigned short& v, const LAS_property::R&)
   { r.set_R(v); }
-  inline void output_value(LASpoint& r, const unsigned short& v, LAS_property::G&)
+  inline void output_value(LASpoint& r, const unsigned short& v, const LAS_property::G&)
   { r.set_G(v); }
-  inline void output_value(LASpoint& r, const unsigned short& v, LAS_property::B&)
+  inline void output_value(LASpoint& r, const unsigned short& v, const LAS_property::B&)
   { r.set_B(v); }
-  inline void output_value(LASpoint& r, const unsigned short& v, LAS_property::I&)
+  inline void output_value(LASpoint& r, const unsigned short& v, const LAS_property::I&)
   { r.set_I(v); }
 
   template <typename ForwardIterator>
@@ -135,6 +135,21 @@ namespace LAS {
     output_value (point, get(current.first, *it), current.second);
   }
 
+  template<typename Value, typename Tuple, std::size_t... Is>
+  void output_tuple(LASpoint& point, const Value& v, const Tuple& t, std::index_sequence<Is...>) {
+    (output_value(point, std::get<Is>(v), std::get<Is>(t)), ...);
+  }
+
+  template <typename ForwardIterator,
+            typename PropertyMap,
+            typename ... T>
+  void output_properties(LASpoint& point,
+                         ForwardIterator it,
+                         std::tuple<PropertyMap, T ...>&& current)
+  {
+    output_tuple(point, get(std::get<0>(current), *it), std::tuple<T ...>(), std::index_sequence_for<T ...>{});
+  }
+
   template <typename ForwardIterator,
             typename PropertyMap,
             typename T,
@@ -151,6 +166,22 @@ namespace LAS {
                        std::forward<PropertyHandler>(properties)...);
   }
 
+  template <typename ForwardIterator,
+            typename PropertyMap,
+            typename ... T,
+            typename NextPropertyHandler,
+            typename ... PropertyHandler>
+  void output_properties(LASpoint& point,
+                         ForwardIterator it,
+                         std::tuple<PropertyMap, T ...>&& current,
+                         NextPropertyHandler&& next,
+                         PropertyHandler&& ... properties)
+  {
+    output_tuple(point, get(std::get<0>(current), *it), std::tuple<T ...>(), std::index_sequence_for<T ...>{});
+    output_properties(point, it, std::forward<NextPropertyHandler>(next),
+                      std::forward<PropertyHandler>(properties)...);
+  }
+
 } // namespace LAS
 } // namespace internal
 
@@ -305,7 +336,7 @@ bool write_LAS(std::ostream& os,
 /**
    \ingroup PkgPointSetProcessing3IOLas
 
-   Saves the range of `points` (positions only), using the \ref IOStreamLAS.
+   writes the range of `points` (positions only), using the \ref IOStreamLAS.
 
    \tparam PointRange is a model of `ConstRange`. The value type of
    its iterator is the key type of the named parameter `point_map`.
@@ -379,11 +410,6 @@ bool write_las_points(std::ostream& os, ///< output stream.
 
 /// \endcond
 
-/**
-  \ingroup PkgPointSetProcessing3IODeprecated
-
-  \deprecated This function is deprecated since \cgal 5.3, `CGAL::IO::write_LAS_with_properties()` should be used instead.
-*/
 template <typename PointRange,
           typename PointMap,
           typename ... PropertyHandler>
@@ -398,11 +424,7 @@ CGAL_DEPRECATED bool write_las_points_with_properties(std::ostream& os,
   return IO::write_LAS_with_properties(os, points, point_property, std::forward<PropertyHandler>(properties)...);
 }
 
-/**
-   \ingroup PkgPointSetProcessing3IODeprecated
 
-  \deprecated This function is deprecated since \cgal 5.3, `CGAL::IO::write_LAS()` should be used instead.
-*/
 template <typename PointRange, typename CGAL_NP_TEMPLATE_PARAMETERS>
 bool write_las_points(std::ostream& os, const PointRange& points, const CGAL_NP_CLASS& np = parameters::default_values())
 {
