@@ -9,8 +9,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Intersections_3/include/CGAL/Intersections_3/Plane_3_Plane_3_Plane_3.h $
-// $Id: Plane_3_Plane_3_Plane_3.h 3a4e230 2022-11-22T12:22:42+01:00 Mael Rouxel-Labbé
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Intersections_3/include/CGAL/Intersections_3/Plane_3_Plane_3_Plane_3.h $
+// $Id: include/CGAL/Intersections_3/Plane_3_Plane_3_Plane_3.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -52,7 +52,7 @@ intersection(const Plane_3<K>& plane1,
 
 template <class K>
 inline
-boost::optional<typename K::Point_3>
+std::optional<typename K::Point_3>
 intersection_point_for_polyhedral_envelope(const Plane_3<K>& p0,
                                            const Plane_3<K>& p1,
                                            const Plane_3<K>& p2)
