@@ -7,8 +7,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6/Kernel_23/include/CGAL/Kernel/global_functions_3.h $
-// $Id: global_functions_3.h d16dfc3 2022-01-27T19:43:21+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Kernel_23/include/CGAL/Kernel/global_functions_3.h $
+// $Id: include/CGAL/Kernel/global_functions_3.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -318,6 +318,24 @@ compare_angle(const Point_3<K>& a, const Point_3<K>& b, const Point_3<K>& c,
   return internal::compare_angle(a, b, c, cosine, K());
 }
 
+template < class K >
+inline
+typename K::Comparison_result
+compare_angle(const Point_3<K>& a1, const Point_3<K>& b1, const Point_3<K>& c1,
+              const Point_3<K>& a2, const Point_3<K>& b2, const Point_3<K>& c2)
+{
+  return internal::compare_angle(a1, b1, c1, a2, b2, c2, K());
+}
+
+template < class K >
+inline
+typename K::Comparison_result
+compare_angle(const Vector_3<K>& u1, const Vector_3<K>& v1,
+              const Vector_3<K>& u2, const Vector_3<K>& v2)
+{
+  return internal::compare_angle(u1, v1, u2, v2, K());
+}
+
 template < class K >
 inline
 typename K::Comparison_result
@@ -1276,6 +1294,22 @@ squared_area(const Point_3<K> &p, const Point_3<K> &q, const Point_3<K> &r)
   return internal::squared_area(p, q, r, K());
 }
 
+template < class K >
+inline
+typename K::FT
+squared_length(const Vector_3<K> &v)
+{
+  return internal::squared_length(v, K());
+}
+
+template < class K >
+inline
+typename K::FT
+squared_length(const Segment_3<K> &s)
+{
+  return internal::squared_length(s, K());
+}
+
 template < class K >
 inline
 typename K::FT
