@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Mesh_3/include/CGAL/Mesh_3/vertex_perturbation.h $
-// $Id: vertex_perturbation.h 8f703b5 2023-01-27T21:48:32+01:00 Mael
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Mesh_3/include/CGAL/Mesh_3/vertex_perturbation.h $
+// $Id: include/CGAL/Mesh_3/vertex_perturbation.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -34,7 +34,7 @@
   #endif
 #endif
 
-#include <boost/optional.hpp>
+#include <optional>
 #include <boost/random/lagged_fibonacci.hpp>
 #include <boost/random/uniform_real.hpp>
 #include <boost/random/variate_generator.hpp>
@@ -115,16 +115,16 @@ typename Tr::Geom_traits::FT
 edge_sq_length(const typename Tr::Edge& e,
                const Tr& tr)
 {
-  typedef typename Tr::Geom_traits     Gt;
+  typedef typename Tr::Geom_traits     GT;
   typedef typename Tr::Bare_point      Bare_point;
   typedef typename Tr::Weighted_point  Weighted_point;
 
   // There is no need to use tr.min_squared_distance() here because we are computing
   // distances between vertices within a common cell, which means that even
   // if we are using a periodic triangulation, the distance is correctly computed.
-  typename Gt::Compute_squared_distance_3 sq_distance =
+  typename GT::Compute_squared_distance_3 sq_distance =
     tr.geom_traits().compute_squared_distance_3_object();
-  typename Gt::Construct_point_3 cp =
+  typename GT::Construct_point_3 cp =
     tr.geom_traits().construct_point_3_object();
 
   const Weighted_point& wp = tr.point(e.first, e.second);
@@ -393,9 +393,9 @@ protected:
   typedef typename Base::Cell_handle                  Cell_handle;
 
   typedef typename C3T3::Triangulation                Tr;
-  typedef typename Tr::Geom_traits                    Gt;
-  typedef typename Gt::FT                             FT;
-  typedef typename Gt::Vector_3                       Vector_3;
+  typedef typename Tr::Geom_traits                    GT;
+  typedef typename GT::FT                             FT;
+  typedef typename GT::Vector_3                       Vector_3;
 
   typedef typename Tr::Bare_point                     Bare_point;
   typedef typename Tr::Weighted_point                 Weighted_point;
@@ -450,15 +450,15 @@ protected:
 
     const Tr& tr = c3t3.triangulation();
 
-    typename Gt::Construct_point_3 cp =
+    typename GT::Construct_point_3 cp =
       tr.geom_traits().construct_point_3_object();
-    typename Gt::Construct_weighted_point_3 cwp =
+    typename GT::Construct_weighted_point_3 cwp =
       tr.geom_traits().construct_weighted_point_3_object();
-    typename Gt::Compute_squared_length_3 sq_length =
+    typename GT::Compute_squared_length_3 sq_length =
       tr.geom_traits().compute_squared_length_3_object();
-    typename Gt::Construct_translated_point_3 translate =
+    typename GT::Construct_translated_point_3 translate =
       tr.geom_traits().construct_translated_point_3_object();
-    typename Gt::Construct_vector_3 vector =
+    typename GT::Construct_vector_3 vector =
       tr.geom_traits().construct_vector_3_object();
 
     // create a helper
@@ -551,9 +551,9 @@ protected:
   typedef typename Base::Vertex_handle                Vertex_handle;
   typedef typename Base::Cell_handle                  Cell_handle;
 
-  typedef typename Tr::Geom_traits                    Gt;
-  typedef typename Gt::FT                             FT;
-  typedef typename Gt::Vector_3                       Vector_3;
+  typedef typename Tr::Geom_traits                    GT;
+  typedef typename GT::FT                             FT;
+  typedef typename GT::Vector_3                       Vector_3;
 
   typedef typename Tr::Bare_point                     Bare_point;
   typedef typename Tr::Weighted_point                 Weighted_point;
@@ -653,9 +653,9 @@ private:
   {
     const Triangulation& tr = c3t3.triangulation();
 
-    typename Gt::Construct_point_3 cp =
+    typename GT::Construct_point_3 cp =
       c3t3.triangulation().geom_traits().construct_point_3_object();
-    typename Gt::Construct_translated_point_3 translate =
+    typename GT::Construct_translated_point_3 translate =
       c3t3.triangulation().geom_traits().construct_translated_point_3_object();
 
     unsigned int index = cell->index(v);
@@ -727,9 +727,9 @@ protected:
   typedef typename Base::Cell_handle                  Cell_handle;
 
   typedef typename C3T3::Triangulation                Tr;
-  typedef typename Tr::Geom_traits                    Gt;
-  typedef typename Gt::FT                             FT;
-  typedef typename Gt::Vector_3                       Vector_3;
+  typedef typename Tr::Geom_traits                    GT;
+  typedef typename GT::FT                             FT;
+  typedef typename GT::Vector_3                       Vector_3;
 
   typedef typename Tr::Bare_point                     Bare_point;
   typedef typename Tr::Weighted_point                 Weighted_point;
@@ -830,7 +830,7 @@ private:
     CGAL_precondition(cell->has_vertex(v));
 
     const typename C3T3::Triangulation& tr = c3t3.triangulation();
-    typename Gt::Construct_point_3 cp = tr.geom_traits().construct_point_3_object();
+    typename GT::Construct_point_3 cp = tr.geom_traits().construct_point_3_object();
 
     const int i = cell->index(v);
 
@@ -878,9 +878,9 @@ protected:
   typedef typename Base::Cell_handle                  Cell_handle;
 
   typedef typename C3T3::Triangulation                Tr;
-  typedef typename Tr::Geom_traits                    Gt;
-  typedef typename Gt::FT                             FT;
-  typedef typename Gt::Vector_3                       Vector_3;
+  typedef typename Tr::Geom_traits                    GT;
+  typedef typename GT::FT                             FT;
+  typedef typename GT::Vector_3                       Vector_3;
 
   typedef typename Tr::Bare_point                     Bare_point;
   typedef typename Tr::Weighted_point                 Weighted_point;
@@ -985,9 +985,9 @@ private:
     // There is no need to use tr.min_squared_distance() here because we are computing
     // distances between vertices within a common cell, which means that even
     // if we are using a periodic triangulation, the distance is correctly computed.
-    typename Gt::Compute_squared_distance_3 sq_distance =
+    typename GT::Compute_squared_distance_3 sq_distance =
       tr.geom_traits().compute_squared_distance_3_object();
-    typename Gt::Construct_point_3 cp =
+    typename GT::Construct_point_3 cp =
       tr.geom_traits().construct_point_3_object();
 
     const int i = cell->index(v);
@@ -1047,9 +1047,9 @@ private:
   {
     const typename C3T3::Triangulation& tr = c3t3.triangulation();
 
-    typename Gt::Construct_point_3 cp =
+    typename GT::Construct_point_3 cp =
       tr.geom_traits().construct_point_3_object();
-    typename Gt::Compute_approximate_dihedral_angle_3 approx_dihedral_angle =
+    typename GT::Compute_approximate_dihedral_angle_3 approx_dihedral_angle =
       tr.geom_traits().compute_approximate_dihedral_angle_3_object();
 
     const Weighted_point& wp1 = tr.point(cell, k1);
@@ -1075,7 +1075,7 @@ private:
   {
     const typename C3T3::Triangulation& tr = c3t3.triangulation();
 
-    typename Gt::Construct_point_3 cp = tr.geom_traits().construct_point_3_object();
+    typename GT::Construct_point_3 cp = tr.geom_traits().construct_point_3_object();
 
     int k1 = (i+1)&3;
     int k2 = (i+2)&3;
@@ -1114,9 +1114,9 @@ protected:
   typedef typename Base::Cell_handle                  Cell_handle;
 
   typedef typename C3T3::Triangulation                Tr;
-  typedef typename Tr::Geom_traits                    Gt;
-  typedef typename Gt::FT                             FT;
-  typedef typename Gt::Vector_3                       Vector_3;
+  typedef typename Tr::Geom_traits                    GT;
+  typedef typename GT::FT                             FT;
+  typedef typename GT::Vector_3                       Vector_3;
 
   typedef typename Tr::Bare_point                     Bare_point;
 
@@ -1177,7 +1177,7 @@ protected:
   Vector_3 random_vector_fixed_size(const C3T3& c3t3,
                                     const FT& vector_sq_size) const
   {
-    typename Gt::Compute_squared_length_3 sq_length =
+    typename GT::Compute_squared_length_3 sq_length =
       c3t3.triangulation().geom_traits().compute_squared_length_3_object();
 
     Vector_3 rnd_vector(random_ft(),random_ft(),random_ft());
@@ -1242,9 +1242,9 @@ protected:
   typedef typename Base::Cell_handle                  Cell_handle;
 
   typedef typename C3T3::Triangulation                Tr;
-  typedef typename Tr::Geom_traits                    Gt;
-  typedef typename Gt::FT                             FT;
-  typedef typename Gt::Vector_3                       Vector_3;
+  typedef typename Tr::Geom_traits                    GT;
+  typedef typename GT::FT                             FT;
+  typedef typename GT::Vector_3                       Vector_3;
 
   typedef typename Tr::Bare_point                     Bare_point;
   typedef typename Tr::Weighted_point                 Weighted_point;
@@ -1319,13 +1319,13 @@ private:
   {
     typedef Triangulation_helpers<typename C3T3::Triangulation> Th;
 
-    typename Gt::Construct_point_3 cp =
+    typename GT::Construct_point_3 cp =
       c3t3.triangulation().geom_traits().construct_point_3_object();
-    typename Gt::Construct_weighted_point_3 cwp =
+    typename GT::Construct_weighted_point_3 cwp =
       c3t3.triangulation().geom_traits().construct_weighted_point_3_object();
-    typename Gt::Construct_translated_point_3 translate =
+    typename GT::Construct_translated_point_3 translate =
       c3t3.triangulation().geom_traits().construct_translated_point_3_object();
-    typename Gt::Construct_vector_3 vector =
+    typename GT::Construct_vector_3 vector =
       c3t3.triangulation().geom_traits().construct_vector_3_object();
 
     modified_vertices.clear();
