@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Mesh_3/include/CGAL/Mesh_cell_criteria_3.h $
-// $Id: Mesh_cell_criteria_3.h cc05187 2022-12-15T15:57:10+01:00 Jane Tournois
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Mesh_3/include/CGAL/Mesh_cell_criteria_3.h $
+// $Id: include/CGAL/Mesh_cell_criteria_3.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -27,11 +27,42 @@
 
 namespace CGAL {
 
-template <typename Tr,
-          typename Visitor_ = Mesh_3::Cell_criterion_visitor_with_radius_lower_bound<Tr> >
+/*!
+\ingroup PkgMesh3MeshClasses
+
+The class `Mesh_cell_criteria_3` is a model of `MeshCellCriteria_3`. It provides,
+for the mesh tetrahedra,
+a uniform shape criterion
+and a sizing field which may be a uniform or variable field.
+
+\tparam Tr must be identical to the nested type
+`Triangulation` of the instance used as model of
+`MeshComplex_3InTriangulation_3`.
+
+\cgalModels{MeshCellCriteria_3}
+
+\sa `MeshCriteria_3`
+\sa `CGAL::Mesh_criteria_3<Tr>`
+\sa `CGAL::make_mesh_3()`
+*/
+template <typename Tr
+#ifndef DOXYGEN_RUNNING
+          ,typename Visitor_ = Mesh_3::Cell_criterion_visitor_with_radius_lower_bound<Tr>
+#endif
+          >
 class Mesh_cell_criteria_3
 {
 public:
+  /// \name Types
+  /// @{
+
+  /*!
+    Numerical type
+  */
+  typedef typename Tr::Geom_traits::FT FT;
+
+  /// @}
+
   typedef Visitor_ Visitor;
   typedef typename Visitor::Cell_quality Cell_quality;
   typedef typename Visitor::Is_cell_bad  Is_cell_bad;
@@ -41,16 +72,28 @@ private:
   typedef Mesh_3::Criteria<Tr,Visitor> Criteria;
 
   typedef typename Tr::Cell_handle Cell_handle;
-  typedef typename Tr::Geom_traits::FT FT;
 
   typedef Mesh_cell_criteria_3<Tr> Self;
 
 public:
 
-  /**
-   * @brief Constructor
-   * @param radius_edge_bound the radius-edge bound
-   * @param radius_bound the radius bound (tet sizing)
+  /// \name Creation
+/// @{
+
+  /*!
+   * Returns an object to serve as default criteria for cells.
+   * @param radius_edge_bound is the upper bound for the radius-edge
+   *                          ratio of the tetrahedra.
+   * @param radius_bound is a uniform upper bound
+                         for the circumradii of the tetrahedra in the mesh
+   *
+   * @param min_radius_bound is a uniform lower bound for the
+   *     circumradii of the tetrahedra in the mesh.
+   *     Only cells with a circumradius larger than that
+   *     bound will be refined.
+   *
+   * See Section \ref introsecparam for further details.
+   * Note that if one parameter is set to 0, then its corresponding criterion is ignored.
    */
   Mesh_cell_criteria_3(const FT& radius_edge_bound,
                        const FT& radius_bound,
@@ -68,13 +111,25 @@ public:
 
   // Nb: SFINAE to avoid wrong matches with built-in numerical types
   // as int.
+
+  /*!
+    Returns an object to serve as default criteria for facets.
+    @tparam SizingField must be a model of the concept
+    `MeshDomainField_3`.
+
+    The behavior and semantic of the arguments are the same
+    as above, except that the radius bound parameter is a functional
+    instead of a constant.
+  */
   template <typename Sizing_field>
-  Mesh_cell_criteria_3(const FT& radius_edge_bound,
-                       const Sizing_field& radius_bound,
-                       const FT& min_radius_bound = 0.,
-                       std::enable_if_t<
+  Mesh_cell_criteria_3(const FT& radius_edge_bound
+                       ,const Sizing_field& radius_bound
+                       ,const FT& min_radius_bound = 0.
+#ifndef DOXYGEN_RUNNING
+                       ,std::enable_if_t<
                          Mesh_3::Is_mesh_domain_field_3<Tr,Sizing_field>::value
                        >* = 0
+#endif
                        )
   {
     if (FT(0) != min_radius_bound)
@@ -86,7 +141,9 @@ public:
       init_radius_edge(radius_edge_bound);
   }
 
-  /// Destructor
+  /// @}
+
+  // Destructor
   ~Mesh_cell_criteria_3() { }
 
   /**
@@ -99,10 +156,12 @@ public:
     return criteria_(tr, cell);
   }
 
+#ifndef DOXYGEN_RUNNING
   void add(Abstract_criterion* criterion)
   {
     criteria_.add(criterion);
   }
+#endif
 
 private:
   void init_radius_edge(const FT& radius_edge_bound)
