@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Nef_2/include/CGAL/Nef_2/HDS_items.h $
-// $Id: HDS_items.h 0779373 2020-03-26T13:31:46+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Nef_2/include/CGAL/Nef_2/HDS_items.h $
+// $Id: include/CGAL/Nef_2/HDS_items.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -19,10 +19,10 @@
 #include <CGAL/basic.h>
 #include <CGAL/tags.h>
 #include <list>
-#include <boost/optional.hpp>
+#include <optional>
 #include <boost/none.hpp>
 #ifndef CGAL_I_DO_WANT_TO_USE_GENINFO
-#include <boost/any.hpp>
+#include <any>
 #endif
 
 namespace CGAL {
@@ -62,7 +62,7 @@ public:
     #ifdef CGAL_I_DO_WANT_TO_USE_GENINFO
     typedef void*  GenPtr;
     #else
-    typedef boost::any GenPtr;
+    typedef std::any GenPtr;
     #endif
 
     typedef typename Traits::Point Point;   // geometric embedding
@@ -73,7 +73,7 @@ private:
     Halfedge_handle              _h;
     Face_handle                  _f;
     Point                        _p;
-    boost::optional<iv_iterator> _ivit;
+    std::optional<iv_iterator> _ivit;
     Mark                         _m;
     GenPtr                       _i;
 public:
@@ -127,7 +127,7 @@ public:
 
     iv_iterator ivit() const { return *_ivit; }
     void set_ivit(iv_iterator it) { _ivit = it; }
-    void reset_ivit() { _ivit = boost::none; }
+    void reset_ivit() { _ivit = std::nullopt; }
 };
 
 
@@ -151,7 +151,7 @@ public:
     #ifdef CGAL_I_DO_WANT_TO_USE_GENINFO
     typedef void*  GenPtr;
     #else
-    typedef boost::any GenPtr;
+    typedef std::any GenPtr;
     #endif
 
     typedef typename std::list<Halfedge_handle>::iterator fc_iterator;
@@ -162,7 +162,7 @@ protected:
     Halfedge_handle              opp, prv, nxt;
     Vertex_handle                _v;
     Face_handle                  _f;
-    boost::optional<fc_iterator> _fcit;
+    std::optional<fc_iterator> _fcit;
     Mark                         _m;
     GenPtr                       _i;
 public:
@@ -223,7 +223,7 @@ public:
 
     fc_iterator fcit() const      { return *_fcit; }
     void set_fcit(fc_iterator it) { _fcit = it; }
-    void reset_fcit()             { _fcit = boost::none; }
+    void reset_fcit()             { _fcit = std::nullopt; }
 
     bool is_hole_entry() const
         /*{\Mop returns true iff |\Mvar| is entry point into a hole face
@@ -248,7 +248,7 @@ public:
     #ifdef CGAL_I_DO_WANT_TO_USE_GENINFO
     typedef void*  GenPtr;
     #else
-    typedef boost::any GenPtr;
+    typedef std::any GenPtr;
     #endif
 
     typedef typename Traits::Mark  Mark;  // mark information
