@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Nef_S2/include/CGAL/Nef_S2/Sphere_map.h $
-// $Id: Sphere_map.h 16bed97 2022-03-17T20:21:12+00:00 Giles Bathgate
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Nef_S2/include/CGAL/Nef_S2/Sphere_map.h $
+// $Id: include/CGAL/Nef_S2/Sphere_map.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -30,7 +30,7 @@
 #define CGAL_NEF_DEBUG 109
 #include <CGAL/Nef_2/debug.h>
 
-#include<boost/optional.hpp>
+#include<optional>
 #include<boost/none.hpp>
 
 namespace CGAL {
@@ -128,7 +128,7 @@ public:
   typedef std::list<Object_handle>                     Object_list;
   typedef typename Object_list::iterator               Object_iterator;
   typedef typename Object_list::const_iterator         Object_const_iterator;
-  typedef boost::optional<Object_iterator>             Optional_object_iterator ;
+  typedef std::optional<Object_iterator>             Optional_object_iterator ;
   typedef Generic_handle_map<Optional_object_iterator> Handle_to_iterator_map;
 
   typedef Sphere_map*       Constructor_parameter;
@@ -226,7 +226,7 @@ public:
   construction means cloning an isomorphic structure and is thus an
   expensive operation.}*/
 
-  Sphere_map(bool = false) : boundary_item_(boost::none),
+  Sphere_map(bool = false) : boundary_item_(std::nullopt),
     svertices_(), sedges_(), sfaces_(), shalfloop_() {}
 
   ~Sphere_map() noexcept(!CGAL_ASSERTIONS_ENABLED)
@@ -236,7 +236,7 @@ public:
     );
   }
 
-  Sphere_map(const Self& D) : boundary_item_(boost::none),
+  Sphere_map(const Self& D) : boundary_item_(std::nullopt),
     svertices_(D.svertices_),
     sedges_(D.sedges_),
     sfaces_(D.sfaces_),
@@ -258,7 +258,7 @@ public:
 
   void clear()
   {
-    boundary_item_.clear(boost::none);
+    boundary_item_.clear(std::nullopt);
     svertices_.destroy();
     sfaces_.destroy();
     while ( shalfedges_begin() != shalfedges_end() )
@@ -268,7 +268,7 @@ public:
 
   template <typename H>
   bool is_sm_boundary_object(H h) const
-  { return boundary_item_[h]!=boost::none; }
+  { return boundary_item_[h]!=std::nullopt; }
 
   template <typename H>
   Object_iterator& sm_boundary_item(H h)
@@ -280,8 +280,8 @@ public:
 
   template <typename H>
   void undef_sm_boundary_item(H h)
-  { CGAL_assertion(boundary_item_[h]!=boost::none);
-    boundary_item_[h] = boost::none; }
+  { CGAL_assertion(boundary_item_[h]!=std::nullopt);
+    boundary_item_[h] = std::nullopt; }
 
   void reset_sm_iterator_hash(Object_iterator it)
   { SVertex_handle sv;
