@@ -5,8 +5,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6/Periodic_3_mesh_3/include/CGAL/Periodic_3_mesh_triangulation_3.h $
-// $Id: Periodic_3_mesh_triangulation_3.h 4b92e10 2023-04-24T13:25:06+02:00 Mael Rouxel-Labbé
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Periodic_3_mesh_3/include/CGAL/Periodic_3_mesh_triangulation_3.h $
+// $Id: include/CGAL/Periodic_3_mesh_triangulation_3.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Mikhail Bogdanov
@@ -917,76 +917,6 @@ public:
     return make_object(s);
   }
 
-  void dual_exact(const Facet& f, const Weighted_point& ws,
-                  Bare_point& cc) const
-  {
-    // first find the offset minimizing the distance between the facet and the fourth point
-    typename Geom_traits::Construct_point_3 construct_point =
-      geom_traits().construct_point_3_object();
-
-    // @fixme need to introduce Compare_power_distances_to_power_sphere_3(3 points, query)
-    typename Geom_traits::Construct_weighted_circumcenter_3 wcc =
-      geom_traits().construct_weighted_circumcenter_3_object();
-    typename Geom_traits::Compare_squared_distance_3 compare_sd =
-      geom_traits().compare_squared_distance_3_object();
-
-    const Cell_handle c = f.first;
-    const int i = f.second;
-
-    const Bare_point fcc = wcc(point(c, (i+1)%4), point(c, (i+2)%4), point(c, (i+3)%4));
-    const Bare_point& s = construct_point(ws);
-
-    bool used_exact = false;
-    std::pair<Bare_point, Offset> pp_fcc = P3T3::internal::construct_periodic_point(fcc, used_exact, geom_traits());
-    std::pair<Bare_point, Offset> pp_s = P3T3::internal::construct_periodic_point(s, used_exact, geom_traits());
-
-    Offset min_off;
-
-    for(int i = 0; i < 3; ++i) {
-      for(int j = 0; j < 3; ++j) {
-        for(int k = 0; k < 3; ++k)
-        {
-          const Offset o(i-1, j-1, k-1);
-
-          if((i == 0 && j == 0 && k == 0) ||
-             compare_sd(fcc, s, fcc, s,
-                        pp_fcc.second, pp_s.second + o,
-                        pp_fcc.second, pp_s.second + min_off) == SMALLER)
-          {
-            min_off = o;
-          }
-        }
-      }
-    }
-
-    typedef typename Kernel_traits<Bare_point>::Kernel                Kernel;
-    typedef Exact_predicates_exact_constructions_kernel               EKernel;
-
-    typedef Cartesian_converter<Kernel, EKernel>                      To_exact;
-    typedef Cartesian_converter<EKernel, Kernel>                      Back_from_exact;
-
-    typedef CGAL::Periodic_3_regular_triangulation_traits_3<EKernel>  Exact_Rt;
-    typedef typename Exact_Rt::Weighted_point_3                       EWeighted_point_3;
-
-    To_exact to_exact;
-    Back_from_exact back_from_exact;
-
-    Exact_Rt etraits(to_exact(domain()));
-    Exact_Rt::Construct_weighted_circumcenter_3 exact_weighted_circumcenter =
-      etraits.construct_weighted_circumcenter_3_object();
-
-    const EWeighted_point_3& cp = to_exact(c->vertex((i+1)%4)->point());
-    const EWeighted_point_3& cq = to_exact(c->vertex((i+2)%4)->point());
-    const EWeighted_point_3& cr = to_exact(c->vertex((i+3)%4)->point());
-    const EWeighted_point_3& cs = to_exact(ws);
-
-    cc = back_from_exact(exact_weighted_circumcenter(cp, cq, cr, cs,
-                                                     pp_fcc.second + get_offset(c, (i+1)%4),
-                                                     pp_fcc.second + get_offset(c, (i+2)%4),
-                                                     pp_fcc.second + get_offset(c, (i+3)%4),
-                                                     pp_s.second + min_off));
-  }
-
   void dual_segment(const Facet& facet, Bare_point& p, Bare_point& q) const
   {
     typename Base::Periodic_segment_3 ps = Base::dual(facet);
