@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Point_set_3/include/CGAL/Point_set_3/IO/LAS.h $
-// $Id: LAS.h eed54a0 2022-11-15T18:45:39+01:00 albert-github
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Point_set_3/include/CGAL/Point_set_3/IO/LAS.h $
+// $Id: include/CGAL/Point_set_3/IO/LAS.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Simon Giraudot
@@ -169,12 +169,6 @@ bool read_LAS(const std::string& fname, CGAL::Point_set_3<Point, Vector>& point_
 
 #ifndef CGAL_NO_DEPRECATED_CODE
 
-/*!
-  \ingroup PkgPointSet3IODeprecated
-
-  \deprecated This function is deprecated since \cgal 5.3,
-              \link PkgPointSet3IO `CGAL::IO::read_LAS()` \endlink should be used instead.
- */
 template <typename Point, typename Vector>
 CGAL_DEPRECATED bool read_las_point_set(std::istream& is, ///< input stream.
                                         CGAL::Point_set_3<Point, Vector>& point_set) ///< point set
@@ -309,25 +303,25 @@ bool write_LAS(std::ostream& os,
 
   if(remove_R)
   {
-    Uchar_map charR, charG, charB;
-    bool foundR, foundG, foundB;
-    boost::tie(charR, foundR) = point_set.template property_map<unsigned char>("r");
-    if(!foundR)
-      boost::tie(charR, foundR) = point_set.template property_map<unsigned char>("red");
-    boost::tie(charG, foundG) = point_set.template property_map<unsigned char>("g");
-    if(!foundG)
-      boost::tie(charG, foundG) = point_set.template property_map<unsigned char>("green");
-    boost::tie(charB, foundB) = point_set.template property_map<unsigned char>("b");
-    if(!foundB)
-      boost::tie(charB, foundB) = point_set.template property_map<unsigned char>("blue");
+    std::optional<Uchar_map> charR, charG, charB;
 
-    if(foundR && foundG && foundB)
+    charR = point_set.template property_map<unsigned char>("r");
+    if(!charR.has_value())
+      charR = point_set.template property_map<unsigned char>("red");
+    charG = point_set.template property_map<unsigned char>("g");
+    if(!charG.has_value())
+      charG = point_set.template property_map<unsigned char>("green");
+    charB = point_set.template property_map<unsigned char>("b");
+    if(!charB.has_value())
+      charB = point_set.template property_map<unsigned char>("blue");
+
+    if(charR.has_value() && charG.has_value() && charB.has_value())
     {
       for(typename Point_set::iterator it = point_set.begin(); it != point_set.end(); ++it)
       {
-        put(R, *it, (unsigned short)(get(charR, *it)));
-        put(G, *it, (unsigned short)(get(charG, *it)));
-        put(B, *it, (unsigned short)(get(charB, *it)));
+        put(R, *it, (unsigned short)(get(charR.value(), *it)));
+        put(G, *it, (unsigned short)(get(charG.value(), *it)));
+        put(B, *it, (unsigned short)(get(charB.value(), *it)));
       }
     }
   }
@@ -405,12 +399,6 @@ bool write_LAS(const std::string& fname,
 
 #ifndef CGAL_NO_DEPRECATED_CODE
 
-/*!
-  \ingroup PkgPointSet3IODeprecated
-
-  \deprecated This function is deprecated since \cgal 5.3,
-              \link PkgPointSet3IO `CGAL::IO::write_LAS()` \endlink should be used instead.
- */
 template <typename Point, typename Vector>
 CGAL_DEPRECATED bool write_las_point_set(std::ostream& os, ///< output stream.
                                          CGAL::Point_set_3<Point, Vector>& point_set)  ///< point set
