@@ -4,8 +4,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6/Polygon_mesh_processing/include/CGAL/Polygon_mesh_processing/internal/Isotropic_remeshing/remesh_impl.h $
-// $Id: remesh_impl.h 4dc91d1 2023-04-12T09:19:55+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Polygon_mesh_processing/include/CGAL/Polygon_mesh_processing/internal/Isotropic_remeshing/remesh_impl.h $
+// $Id: include/CGAL/Polygon_mesh_processing/internal/Isotropic_remeshing/remesh_impl.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -26,8 +26,8 @@
 #include <CGAL/Polygon_mesh_processing/tangential_relaxation.h>
 
 #include <CGAL/AABB_tree.h>
-#include <CGAL/AABB_traits.h>
-#include <CGAL/AABB_triangle_primitive.h>
+#include <CGAL/AABB_traits_3.h>
+#include <CGAL/AABB_triangle_primitive_3.h>
 
 #include <CGAL/property_map.h>
 #include <CGAL/Dynamic_property_map.h>
@@ -44,7 +44,6 @@
 #include <boost/range/join.hpp>
 #include <memory>
 #include <boost/container/flat_set.hpp>
-#include <boost/optional.hpp>
 #include <boost/property_map/function_property_map.hpp>
 
 #include <map>
@@ -55,6 +54,7 @@
 #include <tuple>
 #include <unordered_map>
 #include <unordered_set>
+#include <optional>
 
 #ifdef CGAL_PMP_REMESHING_DEBUG
 #include <CGAL/Polygon_mesh_processing/self_intersections.h>
@@ -73,7 +73,11 @@
 #endif
 
 namespace CGAL {
+
 namespace Polygon_mesh_processing {
+
+template <typename PM, typename VPMap> class Uniform_sizing_field;
+
 namespace internal {
 
   enum Halfedge_status {
@@ -157,15 +161,15 @@ namespace internal {
     template <class Range>
     bool same_range(const Range& r1, const Range& r2)
     {
-      return boost::begin(r1)==boost::begin(r2) &&
-             boost::end(r1)==boost::end(r2);
+      return std::begin(r1)==std::begin(r2) &&
+             std::end(r1)==std::end(r2);
     }
 
     template <class Range1, class Range2>
     bool same_range(const Range1& r1, const Range2& r2)
     {
-      return std::distance(boost::begin(r1), boost::end(r1)) ==
-             std::distance(boost::begin(r2), boost::end(r2));
+      return std::distance(std::begin(r1), std::end(r1)) ==
+             std::distance(std::begin(r2), std::end(r2));
     }
 
   public:
@@ -227,15 +231,13 @@ namespace internal {
 
   template<typename PM,
            typename EdgeConstraintMap,
-           typename VertexPointMap,
-           typename FacePatchMap>
+           typename FacePatchMap,
+           typename SizingFunction>
   bool constraints_are_short_enough(const PM& pmesh,
                                     EdgeConstraintMap ecmap,
-                                    VertexPointMap vpmap,
                                     const FacePatchMap& fpm,
-                                    const double& high)
+                                    const SizingFunction& sizing)
   {
-    double sqh = high*high;
     typedef typename boost::graph_traits<PM>::halfedge_descriptor halfedge_descriptor;
     typedef typename boost::graph_traits<PM>::edge_descriptor     edge_descriptor;
     for(edge_descriptor e : edges(pmesh))
@@ -245,8 +247,7 @@ namespace internal {
             get(ecmap, e) ||
             get(fpm, face(h,pmesh))!=get(fpm, face(opposite(h,pmesh),pmesh)) )
       {
-        if (sqh < CGAL::squared_distance(get(vpmap, source(h, pmesh)),
-                                         get(vpmap, target(h, pmesh))))
+        if (sizing.is_too_long(source(h, pmesh), target(h, pmesh), pmesh))
         {
           return false;
         }
@@ -290,9 +291,9 @@ namespace internal {
     typedef std::vector<Patch_id>                        Patch_id_list;
     typedef std::map<Patch_id,std::size_t>               Patch_id_to_index_map;
 
-    typedef CGAL::AABB_triangle_primitive<GeomTraits,
+    typedef CGAL::AABB_triangle_primitive_3<GeomTraits,
                      typename Triangle_list::iterator>    AABB_primitive;
-    typedef CGAL::AABB_traits<GeomTraits, AABB_primitive> AABB_traits;
+    typedef CGAL::AABB_traits_3<GeomTraits, AABB_primitive> AABB_traits;
     typedef CGAL::AABB_tree<AABB_traits>                  AABB_tree;
 
     typedef typename boost::property_map<
@@ -378,19 +379,17 @@ namespace internal {
       }
     }
 
-
     // split edges of edge_range that have their length > high
     // Note: only used to split a range of edges provided as input
-    template<typename EdgeRange>
+    template<typename EdgeRange, typename SizingFunction>
     void split_long_edges(const EdgeRange& edge_range,
-                          const double& high)
+                          SizingFunction& sizing)
     {
 
 #ifdef CGAL_PMP_REMESHING_VERBOSE
-      Rcpp::Rcout << "Split long edges (" << high << ")...";
+      Rcpp::Rcout << "Split long edges...";
       Rcpp::Rcout.flush();
 #endif
-      double sq_high = high*high;
 
       //collect long edges
       typedef std::pair<halfedge_descriptor, double> H_and_sql;
@@ -401,9 +400,10 @@ namespace internal {
         );
       for(edge_descriptor e : edge_range)
       {
-        double sqlen = sqlength(e);
-        if (sqlen > sq_high)
-          long_edges.emplace(halfedge(e, mesh_), sqlen);
+        const halfedge_descriptor he = halfedge(e, mesh_);
+        std::optional<double> sqlen = sizing.is_too_long(source(he, mesh_), target(he, mesh_), mesh_);
+        if(sqlen != std::nullopt)
+          long_edges.emplace(he, sqlen.value());
       }
 
       //split long edges
@@ -415,7 +415,6 @@ namespace internal {
         //the edge with longest length
         auto eit = long_edges.begin();
         halfedge_descriptor he = eit->first;
-        double sqlen = eit->second;
         long_edges.erase(eit);
 
         //split edge
@@ -434,15 +433,19 @@ namespace internal {
 #ifdef CGAL_PMP_REMESHING_VERY_VERBOSE
         Rcpp::Rcout << "   refinement point : " << refinement_point << std::endl;
 #endif
+        //update sizing field with the new point
+        sizing.register_split_vertex(vnew, mesh_);
 
         //check sub-edges
-        double sqlen_new = 0.25 * sqlen;
-        if (sqlen_new > sq_high)
-        {
-          //if it was more than twice the "long" threshold, insert them
-          long_edges.emplace(hnew, sqlen_new);
-          long_edges.emplace(next(hnew, mesh_), sqlen_new);
-        }
+        //if it was more than twice the "long" threshold, insert them
+        std::optional<double> sqlen_new = sizing.is_too_long(source(hnew, mesh_), target(hnew, mesh_), mesh_);
+        if(sqlen_new != std::nullopt)
+          long_edges.emplace(hnew, sqlen_new.value());
+
+        const halfedge_descriptor hnext = next(hnew, mesh_);
+        sqlen_new = sizing.is_too_long(source(hnext, mesh_), target(hnext, mesh_), mesh_);
+        if (sqlen_new != std::nullopt)
+          long_edges.emplace(hnext, sqlen_new.value());
 
         //insert new edges to keep triangular faces, and update long_edges
         if (!is_border(hnew, mesh_))
@@ -479,13 +482,12 @@ namespace internal {
     // "visits all edges of the mesh
     //if an edge is longer than the given threshold `high`, the edge
     //is split at its midpoint and the two adjacent triangles are bisected (2-4 split)"
-    void split_long_edges(const double& high)
+    template<typename SizingFunction>
+    void split_long_edges(SizingFunction& sizing)
     {
 #ifdef CGAL_PMP_REMESHING_VERBOSE
-      Rcpp::Rcout << "Split long edges (" << high << ")..." << std::endl;
+      Rcpp::Rcout << "Split long edges..." << std::endl;
 #endif
-      double sq_high = high*high;
-
       //collect long edges
       typedef std::pair<halfedge_descriptor, double> H_and_sql;
       std::multiset< H_and_sql, std::function<bool(H_and_sql,H_and_sql)> >
@@ -498,9 +500,10 @@ namespace internal {
       {
         if (!is_split_allowed(e))
           continue;
-        double sqlen = sqlength(e);
-        if(sqlen > sq_high)
-          long_edges.emplace(halfedge(e, mesh_), sqlen);
+        const halfedge_descriptor he = halfedge(e, mesh_);
+        std::optional<double> sqlen = sizing.is_too_long(source(he, mesh_), target(he, mesh_), mesh_);
+        if(sqlen != std::nullopt)
+          long_edges.emplace(halfedge(e, mesh_), sqlen.value());
       }
 
       //split long edges
@@ -512,7 +515,6 @@ namespace internal {
         //the edge with longest length
         auto eit = long_edges.begin();
         halfedge_descriptor he = eit->first;
-        double sqlen = eit->second;
         long_edges.erase(eit);
 
 #ifdef CGAL_PMP_REMESHING_VERBOSE_PROGRESS
@@ -529,7 +531,7 @@ namespace internal {
         Patch_id patch_id_opp = get_patch_id(face(opposite(he, mesh_), mesh_));
 
         //split edge
-        Point refinement_point = this->midpoint(he);
+        Point refinement_point = sizing.split_placement(he, mesh_);
         halfedge_descriptor hnew = CGAL::Euler::split_edge(he, mesh_);
         CGAL_assertion(he == next(hnew, mesh_));
         put(ecmap_, edge(hnew, mesh_), get(ecmap_, edge(he, mesh_)) );
@@ -548,14 +550,19 @@ namespace internal {
         halfedge_added(hnew, status(he));
         halfedge_added(hnew_opp, status(opposite(he, mesh_)));
 
+        //update sizing field with the new point
+        sizing.register_split_vertex(vnew, mesh_);
+
         //check sub-edges
-        double sqlen_new = 0.25 * sqlen;
-        if (sqlen_new > sq_high)
-        {
-          //if it was more than twice the "long" threshold, insert them
-          long_edges.emplace(hnew, sqlen_new);
-          long_edges.emplace(next(hnew, mesh_), sqlen_new);
-        }
+        //if it was more than twice the "long" threshold, insert them
+        std::optional<double> sqlen_new = sizing.is_too_long(source(hnew, mesh_), target(hnew, mesh_), mesh_);
+        if(sqlen_new != std::nullopt)
+          long_edges.emplace(hnew, sqlen_new.value());
+
+        const halfedge_descriptor hnext = next(hnew, mesh_);
+        sqlen_new = sizing.is_too_long(source(hnext, mesh_), target(hnext, mesh_), mesh_);
+        if (sqlen_new != std::nullopt)
+          long_edges.emplace(hnext, sqlen_new.value());
 
         //insert new edges to keep triangular faces, and update long_edges
         if (!is_on_border(hnew))
@@ -574,9 +581,9 @@ namespace internal {
 
           if (snew == PATCH)
           {
-            double sql = sqlength(hnew2);
-            if (sql > sq_high)
-              long_edges.emplace(hnew2, sql);
+            std::optional<double> sql = sizing.is_too_long(source(hnew2, mesh_), target(hnew2, mesh_), mesh_);
+            if(sql != std::nullopt)
+              long_edges.emplace(hnew2, sql.value());
           }
         }
 
@@ -597,9 +604,9 @@ namespace internal {
 
           if (snew == PATCH)
           {
-            double sql = sqlength(hnew2);
-            if (sql > sq_high)
-              long_edges.emplace(hnew2, sql);
+            std::optional<double> sql = sizing.is_too_long(source(hnew2, mesh_), target(hnew2, mesh_), mesh_);
+            if (sql != std::nullopt)
+              long_edges.emplace(hnew2, sql.value());
           }
         }
       }
@@ -621,8 +628,8 @@ namespace internal {
     // "collapses and thus removes all edges that are shorter than a
     // threshold `low`. [...] testing before each collapse whether the collapse
     // would produce an edge that is longer than `high`"
-    void collapse_short_edges(const double& low,
-                              const double& high,
+    template<typename SizingFunction>
+    void collapse_short_edges(const SizingFunction& sizing,
                               const bool collapse_constraints)
     {
       typedef boost::bimap<
@@ -631,22 +638,21 @@ namespace internal {
       typedef typename Boost_bimap::value_type                    short_edge;
 
 #ifdef CGAL_PMP_REMESHING_VERBOSE
-      Rcpp::Rcout << "Collapse short edges (" << low << ", " << high << ")..."
+      Rcpp::Rcout << "Collapse short edges..."
                 << std::endl;
 #endif
 #ifdef CGAL_PMP_REMESHING_VERBOSE_PROGRESS
       Rcpp::Rcout << "Fill bimap...";
       Rcpp::Rcout.flush();
 #endif
-      double sq_low = low*low;
-      double sq_high = high*high;
 
       Boost_bimap short_edges;
       for(edge_descriptor e : edges(mesh_))
       {
-        double sqlen = sqlength(e);
-        if ((sqlen < sq_low) && is_collapse_allowed(e, collapse_constraints))
-          short_edges.insert(short_edge(halfedge(e, mesh_), sqlen));
+        std::optional<double> sqlen = sizing.is_too_short(halfedge(e, mesh_), mesh_);
+        if(sqlen != std::nullopt
+          && is_collapse_allowed(e, collapse_constraints))
+          short_edges.insert(short_edge(halfedge(e, mesh_), sqlen.value()));
       }
 #ifdef CGAL_PMP_REMESHING_VERBOSE_PROGRESS
       Rcpp::Rcout << "done." << std::endl;
@@ -742,7 +748,8 @@ namespace internal {
         for(halfedge_descriptor ha : halfedges_around_target(va, mesh_))
         {
           vertex_descriptor va_i = source(ha, mesh_);
-          if (sqlength(vb, va_i) > sq_high)
+          std::optional<double> sqha = sizing.is_too_long(vb, va_i, mesh_);
+          if (sqha != std::nullopt)
           {
             collapse_ok = false;
             break;
@@ -797,7 +804,7 @@ namespace internal {
           //fix constrained case
           CGAL_assertion((is_constrained(vkept) || is_corner(vkept) || is_on_patch_border(vkept)) ==
                          (is_va_constrained || is_vb_constrained || is_va_on_constrained_polyline || is_vb_on_constrained_polyline));
-          if (fix_degenerate_faces(vkept, short_edges, sq_low, collapse_constraints))
+          if (fix_degenerate_faces(vkept, short_edges, sizing, collapse_constraints))
           {
 #ifdef CGAL_PMP_REMESHING_DEBUG
             debug_status_map();
@@ -807,9 +814,10 @@ namespace internal {
             //insert new/remaining short edges
             for (halfedge_descriptor ht : halfedges_around_target(vkept, mesh_))
             {
-              double sqlen = sqlength(ht);
-              if ((sqlen < sq_low) && is_collapse_allowed(edge(ht, mesh_), collapse_constraints))
-                short_edges.insert(short_edge(ht, sqlen));
+              std::optional<double> sqlen = sizing.is_too_short(ht, mesh_);
+              if (sqlen != std::nullopt
+                && is_collapse_allowed(edge(ht, mesh_), collapse_constraints))
+                short_edges.insert(short_edge(ht, sqlen.value()));
             }
           }
         }//end if(collapse_ok)
@@ -1007,8 +1015,11 @@ namespace internal {
     // "applies an iterative smoothing filter to the mesh.
     // The vertex movement has to be constrained to the vertex tangent plane [...]
     // smoothing algorithm with uniform Laplacian weights"
+    template <class SizingFunction, typename AllowMoveFunctor>
     void tangential_relaxation_impl(const bool relax_constraints/*1d smoothing*/
-                                   , const unsigned int nb_iterations)
+                                  , const unsigned int nb_iterations
+                                  , const SizingFunction& sizing
+                                  , const AllowMoveFunctor& shall_move)
     {
 #ifdef CGAL_PMP_REMESHING_VERBOSE
       Rcpp::Rcout << "Tangential relaxation (" << nb_iterations << " iter.)...";
@@ -1039,16 +1050,43 @@ namespace internal {
       auto constrained_vertices_pmap
         = boost::make_function_property_map<vertex_descriptor>(vertex_constraint);
 
-      tangential_relaxation(
-        vertices(mesh_),
-        mesh_,
-        CGAL::parameters::number_of_iterations(nb_iterations)
-                         .vertex_point_map(vpmap_)
-                         .geom_traits(gt_)
-                         .edge_is_constrained_map(constrained_edges_pmap)
-                         .vertex_is_constrained_map(constrained_vertices_pmap)
-                         .relax_constraints(relax_constraints)
-      );
+      if constexpr (std::is_same_v<SizingFunction, Uniform_sizing_field<PM, VertexPointMap>>)
+      {
+#ifdef CGAL_PMP_REMESHING_VERBOSE
+        Rcpp::Rcout << " using tangential relaxation with weights equal to 1";
+        Rcpp::Rcout << std::endl;
+#endif
+        tangential_relaxation(
+          vertices(mesh_),
+          mesh_,
+          CGAL::parameters::number_of_iterations(nb_iterations)
+            .vertex_point_map(vpmap_)
+            .geom_traits(gt_)
+            .edge_is_constrained_map(constrained_edges_pmap)
+            .vertex_is_constrained_map(constrained_vertices_pmap)
+            .relax_constraints(relax_constraints)
+            .allow_move_functor(shall_move)
+        );
+      }
+      else
+      {
+#ifdef CGAL_PMP_REMESHING_VERBOSE
+        Rcpp::Rcout << " using tangential relaxation weighted with the sizing field";
+        Rcpp::Rcout << std::endl;
+#endif
+        tangential_relaxation(
+          vertices(mesh_),
+          mesh_,
+          CGAL::parameters::number_of_iterations(nb_iterations)
+            .vertex_point_map(vpmap_)
+            .geom_traits(gt_)
+            .edge_is_constrained_map(constrained_edges_pmap)
+            .vertex_is_constrained_map(constrained_vertices_pmap)
+            .relax_constraints(relax_constraints)
+            .sizing_function(sizing)
+            .allow_move_functor(shall_move)
+        );
+      }
 
       CGAL_assertion(!input_mesh_is_valid_ || is_valid_polygon_mesh(mesh_));
 
@@ -1646,10 +1684,10 @@ private:
       // else keep current status for en and eno
     }
 
-    template<typename Bimap>
+    template<typename Bimap, typename SizingFunction>
     bool fix_degenerate_faces(const vertex_descriptor& v,
                               Bimap& short_edges,
-                              const double& sq_low,
+                              const SizingFunction& sizing,
                               const bool collapse_constraints)
     {
       std::unordered_set<halfedge_descriptor> degenerate_faces;
@@ -1667,29 +1705,28 @@ private:
         return true;
 
       bool done = false;
+
       while(!degenerate_faces.empty())
       {
         halfedge_descriptor h = *(degenerate_faces.begin());
         degenerate_faces.erase(degenerate_faces.begin());
 
-        if (!is_degenerate_triangle_face(face(h, mesh_), mesh_,
-                                         parameters::vertex_point_map(vpmap_)
-                                                    .geom_traits(gt_)))
-          //this can happen when flipping h has consequences further in the mesh
-          continue;
-
-        //check that opposite is not also degenerate
-        degenerate_faces.erase(opposite(h, mesh_));
-
-        if(is_border(h, mesh_))
+        if(is_border(opposite(h, mesh_), mesh_))
+        {
+          CGAL::Euler::remove_face(h, mesh_);
           continue;
+        }
 
         for(halfedge_descriptor hf :
             halfedges_around_face(h, mesh_))
         {
-          if(face(opposite(hf, mesh_), mesh_) == boost::graph_traits<PM>::null_face())
-            continue;
+          halfedge_descriptor hfo = opposite(hf, mesh_);
 
+          if(is_border(hfo, mesh_))
+          {
+            CGAL::Euler::remove_face(h, mesh_);
+            break;
+          }
           vertex_descriptor vc = target(hf, mesh_);
           vertex_descriptor va = target(next(hf, mesh_), mesh_);
           vertex_descriptor vb = target(next(next(hf, mesh_), mesh_), mesh_);
@@ -1697,7 +1734,6 @@ private:
           Vector_3 ac(get(vpmap_,va), get(vpmap_,vc));
           if (ab * ac < 0)
           {
-            halfedge_descriptor hfo = opposite(hf, mesh_);
             halfedge_descriptor h_ab = prev(hf, mesh_);
             halfedge_descriptor h_ca = next(hf, mesh_);
 
@@ -1709,6 +1745,16 @@ private:
             if (!is_flip_topologically_allowed(edge(hf, mesh_)))
               continue;
 
+            // geometric condition for flip --> do not create new degenerate face
+            vertex_descriptor vd = target(next(hfo, mesh_), mesh_);
+            if ( collinear( get(vpmap_, va), get(vpmap_, vb), get(vpmap_, vd) ) ||
+                 collinear( get(vpmap_, va), get(vpmap_, vc), get(vpmap_, vd) ) )  continue;
+
+            // remove opposite face from the queue (if degenerate)
+            degenerate_faces.erase(hfo);
+            degenerate_faces.erase(next(hfo, mesh_));
+            degenerate_faces.erase(prev(hfo, mesh_));
+
             CGAL::Euler::flip_edge(hf, mesh_);
             done = true;
 
@@ -1727,22 +1773,11 @@ private:
             //insert new edges in 'short_edges'
             if (is_collapse_allowed(edge(hf, mesh_), collapse_constraints))
             {
-              double sqlen = sqlength(hf);
-              if (sqlen < sq_low)
-                short_edges.insert(typename Bimap::value_type(hf, sqlen));
+              std::optional<double> sqlen = sizing.is_too_short(hf, mesh_);
+              if (sqlen != std::nullopt)
+                short_edges.insert(typename Bimap::value_type(hf, sqlen.value()));
             }
 
-            if(!is_border(hf, mesh_) &&
-               is_degenerate_triangle_face(face(hf, mesh_), mesh_,
-                                           parameters::vertex_point_map(vpmap_)
-                                                      .geom_traits(gt_)))
-              degenerate_faces.insert(hf);
-            if(!is_border(hfo, mesh_) &&
-               is_degenerate_triangle_face(face(hfo, mesh_), mesh_,
-                                           parameters::vertex_point_map(vpmap_)
-                                                      .geom_traits(gt_)))
-              degenerate_faces.insert(hfo);
-
             break;
           }
         }
@@ -1945,7 +1980,7 @@ private:
     bool check_normals(const HalfedgeRange& hedges) const
     {
       std::size_t nb_patches = patch_id_to_index_map.size();
-      //std::vector<boost::optional<Vector_3> > normal_per_patch(nb_patches,boost::none);
+      //std::vector<std::optional<Vector_3> > normal_per_patch(nb_patches,std::nullopt);
       std::vector<bool> initialized(nb_patches,false);
       std::vector<Vector_3> normal_per_patch(nb_patches);
 
@@ -1969,7 +2004,7 @@ private:
             return false;
           }
         }
-        //normal_per_patch[index] = boost::make_optional(n);
+        //normal_per_patch[index] = std::make_optional(n);
         normal_per_patch[index] = n;
         initialized[index] = true;
       }
