@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/QP_solver/include/CGAL/QP_solver/QP_solver_bounds_impl.h $
-// $Id: QP_solver_bounds_impl.h 0779373 2020-03-26T13:31:46+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/QP_solver/include/CGAL/QP_solver/QP_solver_bounds_impl.h $
+// $Id: include/CGAL/QP_solver/QP_solver_bounds_impl.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -13,6 +13,11 @@
 //                 Franz Wessendorp
 //                 Kaspar Fischer
 
+#ifndef CGAL_QP_SOLVER_QP_SOLVER_BOUNDS_IMPL_H
+#define CGAL_QP_SOLVER_QP_SOLVER_BOUNDS_IMPL_H
+
+#include <CGAL/license/QP_solver.h>
+
 namespace CGAL {
 
 template < typename Q, typename ET, typename Tags >
@@ -90,3 +95,5 @@ QP_solver<Q, ET, Tags>::upper_bnd(int i) const
 
 // ===== EOF ==================================================================
 
+#endif //CGAL_QP_SOLVER_QP_SOLVER_BOUNDS_IMPL_H
+
