@@ -4,8 +4,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/GraphicsView/include/CGAL/Qt/DemosMainWindow.h $
-// $Id: DemosMainWindow.h 1a6ece1 2023-04-27T17:27:23+02:00 Laurent Rineau
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/GraphicsView/include/CGAL/Qt/DemosMainWindow.h $
+// $Id: include/CGAL/Qt/DemosMainWindow.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -80,7 +80,9 @@ protected:
   void setupOptionsMenu(QMenu* menu  = nullptr);
   void addAboutCGAL(QMenu* menu  = nullptr);
   void addAboutDemo(QString htmlResourceName, QMenu* menu  = nullptr);
+#if QT_SVG_LIB
   void setupExportSVG(QAction*, QGraphicsView*);
+#endif
 
   void addRecentFiles(QMenu* menu, QAction* insertBefore = nullptr);
 
@@ -90,7 +92,6 @@ protected:
 
 protected Q_SLOTS:
   void setUseAntialiasing(bool checked);
-  void setUseOpenGL(bool checked);
   void popupAboutCGAL();
   void popupAboutDemo();
 
@@ -109,7 +110,6 @@ protected:
   GraphicsViewNavigation* navigation;
   QLabel* xycoord ;
 
-  QAction *actionUse_OpenGL;
   QAction *actionUse_Antialiasing;
   QAction *actionAbout;
   QAction *actionAboutCGAL;
