@@ -6,8 +6,8 @@
  This file is part of a fork of the QGLViewer library version 2.7.0.
 
 *****************************************************************************/
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/GraphicsView/include/CGAL/Qt/manipulatedFrame.h $
-// $Id: manipulatedFrame.h 4547818 2022-11-15T13:39:40+01:00 albert-github
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/GraphicsView/include/CGAL/Qt/manipulatedFrame.h $
+// $Id: include/CGAL/Qt/manipulatedFrame.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-only
 
 #ifndef QGLVIEWER_MANIPULATED_FRAME_H
@@ -270,13 +270,11 @@ private Q_SLOTS:
   /*! @name Mouse event handlers */
   //@{
 protected:
-  virtual void mousePressEvent(QMouseEvent *const event, Camera *const camera);
-  virtual void mouseMoveEvent(QMouseEvent *const event, Camera *const camera);
-  virtual void mouseReleaseEvent(QMouseEvent *const event,
-                                 Camera *const camera);
-  virtual void mouseDoubleClickEvent(QMouseEvent *const event,
-                                     Camera *const camera);
-  virtual void wheelEvent(QWheelEvent *const event, Camera *const camera);
+  void mousePressEvent (QMouseEvent *const event, Camera *const camera) override;
+  void mouseMoveEvent (QMouseEvent *const event, Camera *const camera) override;
+  void mouseReleaseEvent (QMouseEvent *const event, Camera *const camera) override;
+  void mouseDoubleClickEvent(QMouseEvent *const event, Camera *const camera) override;
+  void wheelEvent(QWheelEvent *const event, Camera *const camera) override;
   //@}
 
 public:
@@ -299,7 +297,7 @@ public:
   /*! @name MouseGrabber implementation */
   //@{
 public:
-  virtual void checkIfGrabsMouse(int x, int y, const Camera *const camera);
+  void checkIfGrabsMouse(int x, int y, const Camera *const camera)  override;
   //@}
 
 #ifndef DOXYGEN
