@@ -6,8 +6,8 @@
  This file is part of a fork of the QGLViewer library version 2.7.0.
 
 *****************************************************************************/
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/GraphicsView/include/CGAL/Qt/qglviewer.h $
-// $Id: qglviewer.h 4547818 2022-11-15T13:39:40+01:00 albert-github
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/GraphicsView/include/CGAL/Qt/qglviewer.h $
+// $Id: include/CGAL/Qt/qglviewer.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-only
 
 #ifndef QGLVIEWER_QGLVIEWER_H
@@ -30,10 +30,9 @@
 #include <QVector>
 #include <QElapsedTimer>
 #include <QTimer>
-#include <QGLContext>
 #include <QOpenGLWidget>
 #include <QMouseEvent>
-
+#include <QKeyCombination>
 
 class QTabWidget;
 class QImage;
@@ -71,9 +70,6 @@ class CGAL_QT_EXPORT QGLViewer : public QOpenGLWidget, public QOpenGLFunctions {
   Q_OBJECT
 
 public:
-  //todo check if this is used. If not remove it
-  explicit QGLViewer(QGLContext* context, QWidget *parent = nullptr,
-                     ::Qt::WindowFlags flags = ::Qt::WindowType(0));
   explicit QGLViewer(QOpenGLContext* context, QWidget *parent = nullptr,
                      ::Qt::WindowFlags flags = ::Qt::WindowType(0));
   explicit QGLViewer(QWidget *parent = nullptr,
@@ -482,7 +478,6 @@ public:
   qreal bufferTextureMaxU() const { return bufferTextureMaxU_; }
   /*! Same as bufferTextureMaxU(), but for the v texture coordinate. */
   qreal bufferTextureMaxV() const { return bufferTextureMaxV_; }
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 4, 0))
   // These methods are part of the QGLWidget public API.
   // As of version 2.7.0, the use of QOpenGLWidget instead means that they have
   // to be provided for backward compatibility.
@@ -490,7 +485,6 @@ public:
                   const QFont &font = QFont());
   void renderText(double x, double y, double z, const QString &str,
                   const QFont &font = QFont());
-#endif
 
 public Q_SLOTS:
   void copyBufferToTexture(GLint, GLenum = GL_NONE);
@@ -841,33 +835,27 @@ compatible with raster mode): use \c glRasterPos3fv() instead. */
   /*! @name Keyboard customization */
   //@{
 public:
-  unsigned int shortcut(qglviewer::KeyboardAction action) const;
+  QKeyCombination shortcut(qglviewer::KeyboardAction action) const;
 
   ::Qt::Key pathKey(unsigned int index) const;
   ::Qt::KeyboardModifiers addKeyFrameKeyboardModifiers() const;
   ::Qt::KeyboardModifiers playPathKeyboardModifiers() const;
 
 public Q_SLOTS:
-  void setShortcut(qglviewer::KeyboardAction action, unsigned int key);
+  void setShortcut(qglviewer::KeyboardAction action, QKeyCombination key);
   void setShortcut(qglviewer::KeyboardAction action, ::Qt::Modifier modifier, ::Qt::Key key)
   {
-    setShortcut(action,
-                static_cast<unsigned int>(modifier)+
-                static_cast<unsigned int>(key));
+    setShortcut(action, QKeyCombination{modifier, key});
   }
 
-  void setKeyDescription(unsigned int key, QString description);
+  void setKeyDescription(QKeyCombination key, QString description);
   void setKeyDescription(::Qt::KeyboardModifier modifier, ::Qt::Key key, QString description)
   {
-    setKeyDescription(static_cast<unsigned int>(modifier) +
-                      static_cast<unsigned int>(key),
-                      description);
+    setKeyDescription(QKeyCombination{modifier, key}, description);
   }
   void setKeyDescription(::Qt::Modifier modifier, ::Qt::Key key, QString description)
   {
-    setKeyDescription(static_cast<unsigned int>(modifier) +
-                      static_cast<unsigned int>(key),
-                      description);
+    setKeyDescription(QKeyCombination{modifier, key}, description);
   }
   void clearShortcuts();
 
@@ -1077,8 +1065,8 @@ protected:
   void setDefaultShortcuts();
   QString cameraPathKeysString() const;
   QMap<qglviewer::KeyboardAction, QString> keyboardActionDescription_;
-  QMap<qglviewer::KeyboardAction, unsigned int> keyboardBinding_;
-  QMap<unsigned int, QString> keyDescription_;
+  QMap<qglviewer::KeyboardAction, QKeyCombination> keyboardBinding_;
+  QHash<QKeyCombination, QString> keyDescription_;
 
   // K e y   F r a m e s   s h o r t c u t s
   QMap< ::Qt::Key, unsigned int> pathIndex_;
@@ -1158,7 +1146,7 @@ protected:
         return modifiers < cbp.modifiers;
       if (button != cbp.button)
         return button < cbp.button;
-      return doubleClick != cbp.doubleClick;
+      return doubleClick < cbp.doubleClick;
     }
   };
 #endif
