@@ -4,8 +4,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Shape_regularization/include/CGAL/Shape_regularization/Contours/Longest_direction_2.h $
-// $Id: Longest_direction_2.h 75b03e6 2022-01-10T15:33:04+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Shape_regularization/include/CGAL/Shape_regularization/Contours/Longest_direction_2.h $
+// $Id: include/CGAL/Shape_regularization/Contours/Longest_direction_2.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -43,7 +43,7 @@ namespace Contours {
     range and value type is `GeomTraits::Point_2`. The default is
     `CGAL::Identity_property_map<typename GeomTraits::Point_2>`.
 
-    \cgalModels `ContourDirections`
+    \cgalModels{ContourDirections}
   */
   template<
   typename GeomTraits,
