@@ -4,8 +4,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Surface_mesh/include/CGAL/Surface_mesh/IO/PLY.h $
-// $Id: PLY.h 1e6519e 2023-05-11T17:28:21+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Surface_mesh/include/CGAL/Surface_mesh/IO/PLY.h $
+// $Id: include/CGAL/Surface_mesh/IO/PLY.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -461,12 +461,10 @@ bool fill_simplex_specific_header(std::ostream& os,
     return true;
   }
 
-  bool okay = false;
   if(prop == "v:normal")
   {
-    Vector_map pmap;
-    std::tie(pmap, okay) = sm.template property_map<VIndex, Vector>(prop);
-    if(okay)
+    auto pmap = sm.template property_map<VIndex, Vector>(prop);
+    if(pmap.has_value())
     {
       if(std::is_same<FT, float>::value)
       {
@@ -480,23 +478,22 @@ bool fill_simplex_specific_header(std::ostream& os,
            << "property double ny" << std::endl
            << "property double nz" << std::endl;
       }
-      printers.push_back(new Property_printer<VIndex, Vector_map>(pmap));
+      printers.push_back(new Property_printer<VIndex, Vector_map>(*pmap));
       return true;
     }
   }
 
   if(prop == "v:color")
   {
-    Vcolor_map pmap;
-    std::tie(pmap, okay) = sm.template property_map<VIndex, Color>(prop);
-    if(okay)
+    auto pmap = sm.template property_map<VIndex, Color>(prop);
+    if(pmap.has_value())
     {
       os << "property uchar red" << std::endl
          << "property uchar green" << std::endl
          << "property uchar blue" << std::endl
          << "property uchar alpha" << std::endl;
 
-      printers.push_back(new Property_printer<VIndex, Vcolor_map>(pmap));
+      printers.push_back(new Property_printer<VIndex, Vcolor_map>(*pmap));
       return true;
     }
   }
@@ -518,19 +515,17 @@ bool fill_simplex_specific_header(std::ostream& os,
   if(prop == "f:connectivity" || prop == "f:removed")
     return true;
 
-  bool okay = false;
   if(prop == "f:color")
   {
-    Fcolor_map pmap;
-    std::tie(pmap, okay) = sm.template property_map<FIndex, Color>(prop);
-    if(okay)
+    auto pmap = sm.template property_map<FIndex, Color>(prop);
+    if(pmap.has_value())
     {
       os << "property uchar red" << std::endl
          << "property uchar green" << std::endl
          << "property uchar blue" << std::endl
          << "property uchar alpha" << std::endl;
 
-      printers.push_back(new Property_printer<FIndex, Fcolor_map>(pmap));
+      printers.push_back(new Property_printer<FIndex, Fcolor_map>(*pmap));
       return true;
     }
   }
@@ -642,28 +637,25 @@ void fill_header_impl(std::tuple<T,TN...>,
                       std::vector<Abstract_property_printer<Simplex>*>& printers)
 {
   constexpr std::size_t cid = s-std::tuple_size<std::tuple<T,TN...>>::value;
-  bool okay = false;
   {
     typedef typename Surface_mesh<Point>::template Property_map<Simplex, T>   Pmap;
-    Pmap pmap;
-    std::tie(pmap, okay) = sm.template property_map<Simplex,T>(pname);
-    if(okay)
+    auto pmap  = sm.template property_map<Simplex,T>(pname);
+    if(pmap.has_value())
     {
       std::string name = get_property_raw_name<Point>(pname, Simplex());
       os << "property " << type_strings[cid] << " " << name << std::endl;
-      printers.push_back(new internal::Simple_property_printer<Simplex,Pmap>(pmap));
+      printers.push_back(new internal::Simple_property_printer<Simplex,Pmap>(*pmap));
       return;
     }
   }
   {
     typedef typename Surface_mesh<Point>::template Property_map<Simplex, std::vector<T>>   Pmap;
-    Pmap pmap;
-    std::tie(pmap, okay) = sm.template property_map<Simplex,std::vector<T>>(pname);
-    if(okay)
+    auto pmap  = sm.template property_map<Simplex,std::vector<T>>(pname);
+    if(pmap.has_value())
     {
       std::string name = get_property_raw_name<Point>(pname, Simplex());
       os << "property list uchar " << type_strings[cid] << " " << name << std::endl;
-      printers.push_back(new internal::Simple_property_vector_printer<Simplex,Pmap>(pmap));
+      printers.push_back(new internal::Simple_property_vector_printer<Simplex,Pmap>(*pmap));
       return;
     }
   }
