@@ -2,8 +2,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Surface_mesh_simplification/include/CGAL/Surface_mesh_simplification/Policies/Edge_collapse/LindstromTurk_cost.h $
-// $Id: LindstromTurk_cost.h ff09c5d 2019-10-25T16:35:53+02:00 Mael Rouxel-Labbé
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Surface_mesh_simplification/include/CGAL/Surface_mesh_simplification/Policies/Edge_collapse/LindstromTurk_cost.h $
+// $Id: include/CGAL/Surface_mesh_simplification/Policies/Edge_collapse/LindstromTurk_cost.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Fernando Cacciola <fernando.cacciola@geometryfactory.com>
@@ -32,9 +32,9 @@ public:
   {}
 
   template <typename Profile>
-  boost::optional<typename Profile::FT>
+  std::optional<typename Profile::FT>
   operator()(const Profile& profile,
-             const boost::optional<typename Profile::Point>& placement) const
+             const std::optional<typename Profile::Point>& placement) const
   {
     return internal::LindstromTurkCore<TM, Profile>(m_LT_params, profile).compute_cost(placement);
   }
