@@ -4,8 +4,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6/Tetrahedral_remeshing/include/CGAL/Tetrahedral_remeshing/internal/tetrahedral_adaptive_remeshing_impl.h $
-// $Id: tetrahedral_adaptive_remeshing_impl.h 73063a6 2022-12-21T14:42:39+00:00 Jane Tournois
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Tetrahedral_remeshing/include/CGAL/Tetrahedral_remeshing/internal/tetrahedral_adaptive_remeshing_impl.h $
+// $Id: include/CGAL/Tetrahedral_remeshing/internal/tetrahedral_adaptive_remeshing_impl.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -27,11 +27,14 @@
 #include <CGAL/Tetrahedral_remeshing/internal/collapse_short_edges.h>
 #include <CGAL/Tetrahedral_remeshing/internal/flip_edges.h>
 #include <CGAL/Tetrahedral_remeshing/internal/smooth_vertices.h>
+#include <CGAL/Tetrahedral_remeshing/internal/peel_slivers.h>
+#include <CGAL/Tetrahedral_remeshing/internal/property_maps.h>
 
 #include <CGAL/Tetrahedral_remeshing/internal/tetrahedral_remeshing_helpers.h>
 #include <CGAL/Tetrahedral_remeshing/internal/compute_c3t3_statistics.h>
 
-#include <boost/optional.hpp>
+#include <optional>
+#include <boost/container/small_vector.hpp>
 
 namespace CGAL
 {
@@ -39,6 +42,7 @@ namespace Tetrahedral_remeshing
 {
 namespace internal
 {
+
 class Default_remeshing_visitor
 {
 public:
@@ -56,26 +60,11 @@ public:
   void after_flip(CellHandle /* c */) {}
 };
 
-template<typename Tr>
-struct All_cells_selected
-{
-  using key_type = typename Tr::Cell_handle;
-  using value_type = bool;
-  using reference = bool;
-  using category = boost::read_write_property_map_tag;
-
-  friend value_type get(const All_cells_selected&, const key_type& c)
-  {
-    using SI = typename Tr::Cell::Subdomain_index;
-    return c->subdomain_index() != SI();
-  }
-  friend void put(All_cells_selected&, const key_type&, const value_type)
-  {} //nothing to do : subdomain indices are updated in remeshing};
-};
 
 
 template<typename Triangulation
          , typename SizingFunction
+         , typename VertexIsConstrainedMap
          , typename EdgeIsConstrainedMap
          , typename FacetIsConstrainedMap
          , typename CellSelector
@@ -92,12 +81,13 @@ class Adaptive_remesher
 
   typedef typename C3t3::Cell_handle         Cell_handle;
   typedef typename C3t3::Vertex_handle       Vertex_handle;
+  typedef typename C3t3::Edge                Edge;
   typedef typename C3t3::Subdomain_index     Subdomain_index;
   typedef typename C3t3::Surface_patch_index Surface_patch_index;
   typedef typename C3t3::Curve_index         Curve_index;
   typedef typename C3t3::Corner_index        Corner_index;
 
-  typedef Tetrahedral_remeshing_smoother<C3t3> Smoother;
+  typedef Tetrahedral_remeshing_smoother<C3t3, SizingFunction, CellSelector> Smoother;
 
 private:
   C3t3 m_c3t3;
@@ -108,12 +98,14 @@ private:
   Smoother m_vertex_smoother;//initialized with initial surface
 
   C3t3* m_c3t3_pbackup;
+  std::vector<Vertex_handle> m_far_points;
   Triangulation* m_tr_pbackup; //backup to re-swap triangulations when done
 
 public:
   Adaptive_remesher(Triangulation& tr
                     , const SizingFunction& sizing
                     , const bool protect_boundaries
+                    , VertexIsConstrainedMap vcmap
                     , EdgeIsConstrainedMap ecmap
                     , FacetIsConstrainedMap fcmap
                     , bool smooth_constrained_edges
@@ -125,13 +117,14 @@ public:
     , m_protect_boundaries(protect_boundaries)
     , m_cell_selector(cell_selector)
     , m_visitor(visitor)
+    , m_vertex_smoother(sizing, cell_selector, protect_boundaries, smooth_constrained_edges)
     , m_c3t3_pbackup(NULL)
     , m_tr_pbackup(&tr)
   {
     m_c3t3.triangulation().swap(tr);
 
-    init_c3t3(ecmap, fcmap);
-    m_vertex_smoother.init(m_c3t3, m_cell_selector, smooth_constrained_edges);
+    init_c3t3(vcmap, ecmap, fcmap);
+    m_vertex_smoother.init(m_c3t3);
 
 #ifdef CGAL_DUMP_REMESHING_STEPS
     CGAL::Tetrahedral_remeshing::debug::dump_c3t3(m_c3t3, "00-init");
@@ -143,6 +136,7 @@ public:
   Adaptive_remesher(C3t3& c3t3
                     , const SizingFunction& sizing
                     , const bool protect_boundaries
+                    , VertexIsConstrainedMap vcmap
                     , EdgeIsConstrainedMap ecmap
                     , FacetIsConstrainedMap fcmap
                     , bool smooth_constrained_edges
@@ -154,13 +148,14 @@ public:
     , m_protect_boundaries(protect_boundaries)
     , m_cell_selector(cell_selector)
     , m_visitor(visitor)
+    , m_vertex_smoother(sizing, cell_selector, protect_boundaries, smooth_constrained_edges)
     , m_c3t3_pbackup(&c3t3)
     , m_tr_pbackup(NULL)
   {
     m_c3t3.swap(c3t3);
 
-    init_c3t3(ecmap, fcmap);
-    m_vertex_smoother.init(m_c3t3, m_cell_selector, smooth_constrained_edges);
+    init_c3t3(vcmap, ecmap, fcmap);
+    m_vertex_smoother.init(m_c3t3);
 
 #ifdef CGAL_DUMP_REMESHING_STEPS
     CGAL::Tetrahedral_remeshing::debug::dump_c3t3(m_c3t3, "00-init");
@@ -177,10 +172,7 @@ public:
   void split()
   {
     CGAL_assertion(check_vertex_dimensions());
-
-    const FT target_edge_length = m_sizing(CGAL::ORIGIN);
-    const FT emax = FT(4)/FT(3) * target_edge_length;
-    split_long_edges(m_c3t3, emax, m_protect_boundaries,
+    split_long_edges(m_c3t3, m_sizing, m_protect_boundaries,
                      m_cell_selector, m_visitor);
 
 #ifdef CGAL_TETRAHEDRAL_REMESHING_DEBUG
@@ -191,6 +183,10 @@ public:
     CGAL::Tetrahedral_remeshing::debug::dump_vertices_by_dimension(
       m_c3t3.triangulation(), "1-c3t3_vertices_after_split");
     CGAL::Tetrahedral_remeshing::debug::check_surface_patch_indices(m_c3t3);
+    CGAL::Tetrahedral_remeshing::debug::dump_edges_in_complex(m_c3t3,
+      "1-edges_in_complex_after_split.polylines.txt");
+    const double mdh = CGAL::Tetrahedral_remeshing::min_dihedral_angle(m_c3t3);
+    Rcpp::Rcout << "Min dihedral angle = " << mdh << std::endl;
 #endif
 #ifdef CGAL_DUMP_REMESHING_STEPS
     CGAL::Tetrahedral_remeshing::debug::dump_c3t3(m_c3t3, "1-split");
@@ -200,11 +196,7 @@ public:
   void collapse()
   {
     CGAL_assertion(check_vertex_dimensions());
-
-    const FT target_edge_length = m_sizing(CGAL::ORIGIN);
-    FT emin = FT(4)/FT(5) * target_edge_length;
-    FT emax = FT(4)/FT(3) * target_edge_length;
-    collapse_short_edges(m_c3t3, emin, emax, m_protect_boundaries,
+    collapse_short_edges(m_c3t3, m_sizing, m_protect_boundaries,
                          m_cell_selector, m_visitor);
 
 #ifdef CGAL_TETRAHEDRAL_REMESHING_DEBUG
@@ -213,6 +205,10 @@ public:
     CGAL::Tetrahedral_remeshing::debug::dump_vertices_by_dimension(
       m_c3t3.triangulation(), "2-c3t3_vertices_after_collapse");
     CGAL::Tetrahedral_remeshing::debug::check_surface_patch_indices(m_c3t3);
+    CGAL::Tetrahedral_remeshing::debug::dump_edges_in_complex(m_c3t3,
+      "2-edges_in_complex_after_collapse.polylines.txt");
+    const double mdh = CGAL::Tetrahedral_remeshing::min_dihedral_angle(m_c3t3);
+    Rcpp::Rcout << "Min dihedral angle = " << mdh << std::endl;
 #endif
 #ifdef CGAL_DUMP_REMESHING_STEPS
     CGAL::Tetrahedral_remeshing::debug::dump_c3t3(m_c3t3, "2-collapse");
@@ -230,6 +226,10 @@ public:
     CGAL::Tetrahedral_remeshing::debug::dump_vertices_by_dimension(
       m_c3t3.triangulation(), "3-c3t3_vertices_after_flip");
     CGAL::Tetrahedral_remeshing::debug::check_surface_patch_indices(m_c3t3);
+    CGAL::Tetrahedral_remeshing::debug::dump_edges_in_complex(m_c3t3,
+      "3-edges_in_complex_after_flip.polylines.txt");
+    const double mdh = CGAL::Tetrahedral_remeshing::min_dihedral_angle(m_c3t3);
+    Rcpp::Rcout << "Min dihedral angle = " << mdh << std::endl;
 #endif
 #ifdef CGAL_DUMP_REMESHING_STEPS
     CGAL::Tetrahedral_remeshing::debug::dump_c3t3(m_c3t3, "3-flip");
@@ -238,7 +238,7 @@ public:
 
   void smooth()
   {
-    m_vertex_smoother.smooth_vertices(m_c3t3, m_protect_boundaries, m_cell_selector);
+    m_vertex_smoother.smooth_vertices(m_c3t3);
 
 #ifdef CGAL_TETRAHEDRAL_REMESHING_DEBUG
     CGAL_assertion(tr().tds().is_valid(true));
@@ -246,6 +246,10 @@ public:
     CGAL::Tetrahedral_remeshing::debug::dump_vertices_by_dimension(
       m_c3t3.triangulation(), "4-c3t3_vertices_after_smooth");
     CGAL::Tetrahedral_remeshing::debug::check_surface_patch_indices(m_c3t3);
+    CGAL::Tetrahedral_remeshing::debug::dump_edges_in_complex(m_c3t3,
+      "4-edges_in_complex_after_smoothing.polylines.txt");
+    const double mdh = CGAL::Tetrahedral_remeshing::min_dihedral_angle(m_c3t3);
+    Rcpp::Rcout << "Min dihedral angle = " << mdh << std::endl;
 #endif
 #ifdef CGAL_DUMP_REMESHING_STEPS
     CGAL::Tetrahedral_remeshing::debug::dump_c3t3(m_c3t3, "4-smooth");
@@ -254,30 +258,22 @@ public:
 
   bool resolution_reached()
   {
-    const FT target_edge_length = m_sizing(CGAL::ORIGIN);
-
-    FT emax = FT(4) / FT(3) * target_edge_length;
-    FT emin = FT(4) / FT(5) * target_edge_length;
-
-    FT sqmax = emax * emax;
-    FT sqmin = emin * emin;
-
-    typedef typename Tr::Edge Edge;
-    for (Edge e : tr().finite_edges())
+    for (const Edge& e : tr().finite_edges())
     {
       // skip protected edges
-      if (m_protect_boundaries)
-      {
-        if(  m_c3t3.is_in_complex(e)
-             || is_boundary(m_c3t3, e, m_cell_selector))
-          continue;
-      }
+      const bool boundary =
+        m_c3t3.is_in_complex(e) || is_boundary(m_c3t3, e, m_cell_selector);
+      if (m_protect_boundaries && boundary)
+        continue;
 
-      FT sqlen = tr().segment(e).squared_length();
-      if (sqlen < sqmin || sqlen > sqmax)
+      if(  is_too_long(e, boundary, m_sizing, m_c3t3, m_cell_selector)
+        || is_too_short(e, boundary, m_sizing, m_c3t3, m_cell_selector))
         return false;
     }
+
+#ifdef CGAL_TETRAHEDRAL_REMESHING_VERBOSE
     Rcpp::Rcout << "Resolution reached" << std::endl;
+#endif
     return true;
   }
 
@@ -292,67 +288,8 @@ public:
     Rcpp::Rcout.flush();
 #endif
 
-    std::size_t nb_slivers_peel = 0;
-    std::vector<std::pair<Cell_handle, std::array<bool, 4> > > peelable_cells;
-#ifdef CGAL_TETRAHEDRAL_REMESHING_VERBOSE
-    double mindh = 180.;
-#endif
-    for (Cell_handle cit : tr().finite_cell_handles())
-    {
-      std::array<bool, 4> facets_on_surface;
-      if (m_c3t3.is_in_complex(cit))
-      {
-        const double dh = min_dihedral_angle(tr(), cit);
-        if(dh < sliver_angle && is_peelable(m_c3t3, cit, facets_on_surface))
-          peelable_cells.push_back(std::make_pair(cit, facets_on_surface));
-
-#ifdef CGAL_TETRAHEDRAL_REMESHING_VERBOSE
-        mindh = (std::min)(dh, mindh);
-#endif
-      }
-    }
-
-#ifdef CGAL_TETRAHEDRAL_REMESHING_VERBOSE
-    Rcpp::Rcout << "Min dihedral angle : " << mindh << std::endl;
-    Rcpp::Rcout << "Peelable cells : " << peelable_cells.size() << std::endl;
-#endif
-
-    for (auto c_i : peelable_cells)
-    {
-      Cell_handle c = c_i.first;
-      const std::array<bool, 4>& f_on_surface = c_i.second;
-
-      boost::optional<Surface_patch_index> patch;
-      for (int i = 0; i < 4; ++i)
-      {
-        if (f_on_surface[i])
-        {
-          Surface_patch_index spi = m_c3t3.surface_patch_index(c, i);
-          if (patch != boost::none && patch != spi)
-          {
-            patch = boost::none;
-            break;
-          }
-          else
-          {
-            patch = spi;
-          }
-        }
-      }
-      if(patch == boost::none)
-        continue;
-
-      for (int i = 0; i < 4; ++i)
-      {
-        if(f_on_surface[i])
-          m_c3t3.remove_from_complex(c, i);
-        else
-          m_c3t3.add_to_complex(c, i, patch.get());
-      }
-
-      m_c3t3.remove_from_complex(c);
-      ++nb_slivers_peel;
-    }
+    const std::size_t nb_peeled
+      = CGAL::Tetrahedral_remeshing::peel_slivers(m_c3t3, sliver_angle, m_cell_selector);
 
 #ifdef CGAL_TETRAHEDRAL_REMESHING_DEBUG
     CGAL_assertion(tr().tds().is_valid(true));
@@ -361,33 +298,26 @@ public:
 #ifdef CGAL_DUMP_REMESHING_STEPS
     CGAL::Tetrahedral_remeshing::debug::dump_c3t3(m_c3t3, "99-postprocess");
 #endif
-#ifdef CGAL_TETRAHEDRAL_REMESHING_VERBOSE
-    mindh = 180.;
-    for (Cell_handle cit : tr().finite_cell_handles())
-    {
-      if (m_c3t3.is_in_complex(cit))
-      {
-        const double dh = min_dihedral_angle(tr(), cit);
-        mindh = (std::min)(dh, mindh);
-      }
-    }
-    Rcpp::Rcout << "Peeling done (removed " << nb_slivers_peel << " slivers, "
-      << "min dihedral angle = " << mindh << ")." << std::endl;
 
-#endif
-    return nb_slivers_peel;
+    return nb_peeled;
   }
 
   void finalize()
   {
-    if (m_c3t3_pbackup != NULL)
+    if (input_is_c3t3())
+    {
+      //reset far points dimension
+      for (Vertex_handle v : m_far_points)
+        v->set_dimension(-1);
       m_c3t3_pbackup->swap(m_c3t3);
+    }
     else
       m_tr_pbackup->swap(m_c3t3.triangulation());
   }
 
 private:
-  void init_c3t3(const EdgeIsConstrainedMap& ecmap,
+  void init_c3t3(const VertexIsConstrainedMap& vcmap,
+                 const EdgeIsConstrainedMap& ecmap,
                  const FacetIsConstrainedMap& fcmap)
   {
 #ifdef CGAL_TETRAHEDRAL_REMESHING_DEBUG
@@ -400,31 +330,40 @@ private:
     //update number_of_cells and number_of_facets in c3t3
     m_c3t3.rescan_after_load_of_triangulation();
 
+#ifdef CGAL_TETRAHEDRAL_REMESHING_DEBUG
+    CGAL::Tetrahedral_remeshing::debug::dump_vertices_by_dimension(
+      m_c3t3.triangulation(), "00-c3t3_vertices_before_init_");
+#endif
+
+    if (input_is_c3t3())
+      backup_far_points();
+
+    const Subdomain_index default_subdomain = default_subdomain_index();
+
     //tag cells
     for (Cell_handle cit : tr().finite_cell_handles())
     {
       if (get(m_cell_selector, cit))
       {
         const Subdomain_index index = cit->subdomain_index();
-        if(!input_is_c3t3())
+        if (m_c3t3.is_in_complex(cit))
           m_c3t3.remove_from_complex(cit);
-        if(Subdomain_index() != index)
-          m_c3t3.add_to_complex(cit, index);
+
+        const Subdomain_index new_index = (Subdomain_index() != index)
+          ? index
+          : default_subdomain;
+        m_c3t3.add_to_complex(cit, new_index);
 
 #ifdef CGAL_TETRAHEDRAL_REMESHING_DEBUG
         ++nbc;
 #endif
       }
-      if (!input_is_c3t3())
-      {
-        for (int i = 0; i < 4; ++i)
-        {
-          if (cit->vertex(i)->in_dimension() == -1)
-            cit->vertex(i)->set_dimension(3);
-        }
-      }
+
+      for (Vertex_handle vi : tr().vertices(cit))
+        set_dimension(vi, 3);
+
 #ifdef CGAL_TETRAHEDRAL_REMESHING_DEBUG
-      else if (input_is_c3t3() && m_c3t3.is_in_complex(cit))
+      if (input_is_c3t3() && m_c3t3.is_in_complex(cit))
         ++nbc;
 #endif
     }
@@ -439,20 +378,20 @@ private:
       if (s1 != s2
           || get(fcmap, f)
           || get(fcmap, mf)
-          || (m_c3t3_pbackup == NULL && f.first->is_facet_on_surface(f.second)))
+          || (input_is_c3t3() && m_c3t3.is_in_complex(f))
+          || (!input_is_c3t3() && f.first->is_facet_on_surface(f.second)))
       {
         Surface_patch_index patch = f.first->surface_patch_index(f.second);
         if(patch == Surface_patch_index())
-          set_surface_patch_index_to_default(s1, s2, patch);
+          make_surface_patch_index(s1, s2, patch);
+
+        if(m_c3t3.is_in_complex(f))
+          m_c3t3.remove_from_complex(f);
         m_c3t3.add_to_complex(f, patch);
 
-        const int i = f.second;
-        for (int j = 0; j < 3; ++j)
-        {
-          Vertex_handle vij = f.first->vertex(Tr::vertex_triple_index(i, j));
-          if (vij->in_dimension() == -1 || vij->in_dimension() > 2)
-            vij->set_dimension(2);
-        }
+        for (Vertex_handle vij : tr().vertices(f))
+          set_dimension(vij, 2);
+
 #ifdef CGAL_TETRAHEDRAL_REMESHING_DEBUG
         ++nbf;
 #endif
@@ -463,32 +402,27 @@ private:
 #endif
 
     //tag edges
-    typedef typename Tr::Edge Edge;
+    const Curve_index default_curve_id = default_curve_index();
     for (const Edge& e : tr().finite_edges())
     {
-      if (m_c3t3.is_in_complex(e))
-      {
-        CGAL_assertion(m_c3t3.in_dimension(e.first->vertex(e.second)) <= 1);
-        CGAL_assertion(m_c3t3.in_dimension(e.first->vertex(e.third)) <= 1);
-#ifdef CGAL_TETRAHEDRAL_REMESHING_DEBUG
-        ++nbe;
-#endif
-        continue;
-      }
-
-      if (get(ecmap, CGAL::Tetrahedral_remeshing::make_vertex_pair<Tr>(e))
+      if (get(ecmap, CGAL::Tetrahedral_remeshing::make_vertex_pair(e))
+          || get(ecmap, CGAL::Tetrahedral_remeshing::make_inv_vertex_pair(e))
+          || (input_is_c3t3() && m_c3t3.is_in_complex(e))
           || nb_incident_subdomains(e, m_c3t3) > 2
-          || nb_incident_surface_patches(e, m_c3t3) > 1)
+          || nb_incident_surface_patches(e, m_c3t3) > 1
+          || nb_incident_complex_facets(e, m_c3t3) > 2)//non-manifold edges
       {
-        m_c3t3.add_to_complex(e, 1);
+        const bool in_complex = m_c3t3.is_in_complex(e);
+        typename C3t3::Curve_index curve_id = in_complex
+          ? m_c3t3.curve_index(e)
+          : default_curve_id;
 
-        Vertex_handle v = e.first->vertex(e.second);
-        if (v->in_dimension() == -1 || v->in_dimension() > 1)
-          v->set_dimension(1);
+        if (in_complex)
+          m_c3t3.remove_from_complex(e);
+        m_c3t3.add_to_complex(e, curve_id);
 
-        v = e.first->vertex(e.third);
-        if (v->in_dimension() == -1 || v->in_dimension() > 1)
-          v->set_dimension(1);
+        for (Vertex_handle v : tr().vertices(e))
+          set_dimension(v, 1);
 
 #ifdef CGAL_TETRAHEDRAL_REMESHING_DEBUG
         ++nbe;
@@ -503,15 +437,19 @@ private:
     Corner_index corner_id = 0;
     for (Vertex_handle vit : tr().finite_vertex_handles())
     {
-      if ( vit->in_dimension() == 0
-           || nb_incident_complex_edges(vit, m_c3t3) > 2)
+      boost::container::small_vector<Edge, 3> incident_edges;
+      incident_complex_edges(vit, m_c3t3, std::back_inserter(incident_edges));
+      if ( incident_edges.size() == 1 //tip or endpoint
+        || incident_edges.size() > 2  //corner
+        || get(vcmap, vit) // constrained vertex
+        || (input_is_c3t3() && m_c3t3.is_in_complex(vit))
+        || (incident_edges.size() == 2
+            && edges_form_a_sharp_angle(incident_edges, 60, m_c3t3)))
       {
-        if(!m_c3t3.is_in_complex(vit))
+        if (!m_c3t3.is_in_complex(vit))
           m_c3t3.add_to_complex(vit, ++corner_id);
 
-        if (vit->in_dimension() == -1 || vit->in_dimension() > 0)
-          vit->set_dimension(0);
-
+        set_dimension(vit, 0);
         vit->set_index(corner_id);
 
 #ifdef CGAL_TETRAHEDRAL_REMESHING_DEBUG
@@ -520,6 +458,7 @@ private:
       }
     }
 
+    // set all indices depending on underlying dimension
     for (Vertex_handle v : tr().finite_vertex_handles())
       set_index(v, m_c3t3);
 
@@ -529,14 +468,52 @@ private:
     Rcpp::Rcout << "\t facets   = " << nbf << std::endl;
     Rcpp::Rcout << "\t edges    = " << nbe << std::endl;
     Rcpp::Rcout << "\t vertices = " << nbv << std::endl;
+    const double mdh = CGAL::Tetrahedral_remeshing::min_dihedral_angle(m_c3t3);
+    Rcpp::Rcout << "\t Min dihedral angle = " << mdh << std::endl;
 
     CGAL::Tetrahedral_remeshing::debug::dump_vertices_by_dimension(
-      m_c3t3.triangulation(), "c3t3_vertices_");
+      m_c3t3.triangulation(), "0-c3t3_vertices_after_init_");
     CGAL::Tetrahedral_remeshing::debug::check_surface_patch_indices(m_c3t3);
+    CGAL::Tetrahedral_remeshing::debug::count_far_points(m_c3t3);
+    CGAL::Tetrahedral_remeshing::debug::dump_edges_in_complex(m_c3t3,
+      "0-edges_in_complex_after_init.polylines.txt");
 #endif
   }
 
+  void backup_far_points()
+  {
+    for (Vertex_handle v : tr().finite_vertex_handles())
+    {
+      if (v->in_dimension() == -1)
+        m_far_points.push_back(v);
+    }
+  }
+
 private:
+  bool dimension_is_modifiable(const Vertex_handle& v, const int new_dim) const
+  {
+    const int vdim = v->in_dimension();
+    // feature edges and tip/endpoints vertices are kept
+    switch (vdim)
+    {
+    case -1: return (new_dim == 3);//far points
+    case 3 : return true;
+    case 2 : return true;//surface vertices may not be part of a triangulation surface
+                        // in this case, we want to be able to set it
+    case 1 : return new_dim == 0; //features can be modified to corners
+    case 0 : return false;// corners remain corners
+    default: break;
+    }
+    CGAL_assertion(false);
+    return true;
+  }
+
+  void set_dimension(Vertex_handle v, const int new_dim)
+  {
+    if (dimension_is_modifiable(v, new_dim))
+      v->set_dimension(new_dim);
+  }
+
   bool check_vertex_dimensions()
   {
     for (Vertex_handle vit : tr().finite_vertex_handles())
@@ -550,31 +527,66 @@ private:
   }
   void debug_c3t3()
   {
-    for (typename Tr::Facet f : tr().finite_facets())
+    CGAL_assertion_code(for (typename Tr::Facet f : tr().finite_facets()))
     {
-      typename Tr::Facet mf = tr().mirror_facet(f);
+      CGAL_assertion_code(typename Tr::Facet mf = tr().mirror_facet(f));
       CGAL_assertion(m_c3t3.is_in_complex(f) == m_c3t3.is_in_complex(mf));
     }
   }
 
   template<typename PatchIndex>
-  void set_surface_patch_index_to_default(const Subdomain_index&,
-                                          const Subdomain_index&,
-                                          PatchIndex& patch)
+  void make_surface_patch_index(const Subdomain_index& s1,
+                                const Subdomain_index& s2,
+                                PatchIndex& patch)
   {
-    if(m_c3t3.number_of_facets() == 0)
-      patch = 1;
-    else
-      patch = m_c3t3.surface_patch_index(*m_c3t3.facets_in_complex_begin());
+    patch = (s1 < s2) ? (s1 * 1000 + s2) : (s2 * 1000 + s1);
   }
 
-  void set_surface_patch_index_to_default(const Subdomain_index& s1,
-                                          const Subdomain_index& s2,
-                                          std::pair<Subdomain_index, Subdomain_index>& patch)
+  void make_surface_patch_index(const Subdomain_index& s1,
+                                const Subdomain_index& s2,
+                                std::pair<Subdomain_index, Subdomain_index>& patch)
   {
     patch = (s1 < s2) ? std::make_pair(s1, s2) : std::make_pair(s2, s1);
   }
 
+  Subdomain_index max_subdomain_index() const
+  {
+    Subdomain_index max_index
+      = (std::numeric_limits<Subdomain_index>::min)();
+    for (Cell_handle cit : tr().finite_cell_handles())
+    {
+      const Subdomain_index cid = cit->subdomain_index();
+      if (cid > max_index && cid != Subdomain_index())
+        max_index = cid;
+    }
+    return max_index;
+  }
+
+  Subdomain_index default_subdomain_index() const
+  {
+    return max_subdomain_index() + 1;
+  }
+
+  Curve_index max_curve_index() const
+  {
+    Curve_index max_index = (std::numeric_limits<Curve_index>::min)();
+    for (const Edge& e : m_c3t3.edges_in_complex())
+    {
+      const Curve_index cid = m_c3t3.curve_index(e);
+      if (cid > max_index)
+        max_index = cid;
+    }
+    if (max_index == (std::numeric_limits<Curve_index>::min)())
+      return 0;
+    else
+      return max_index + 1;
+  }
+
+  Curve_index default_curve_index() const
+  {
+    return max_curve_index() + 1;
+  }
+
 public:
   Tr& tr()
   {
@@ -613,12 +625,16 @@ public:
       ossi << "statistics_" << it_nb << ".txt";
       Tetrahedral_remeshing::internal::compute_statistics(
         tr(), m_cell_selector, ossi.str().c_str());
+      std::ostringstream oss_it;
+      oss_it << "iteration_" << it_nb;
+      Tetrahedral_remeshing::debug::dump_c3t3(m_c3t3, oss_it.str().c_str());
 #endif
 #ifdef CGAL_TETRAHEDRAL_REMESHING_DEBUG
       CGAL::Tetrahedral_remeshing::debug::check_surface_patch_indices(m_c3t3);
 #endif
     }
 
+    m_vertex_smoother.start_flip_smooth_steps(m_c3t3);
     while (it_nb < max_it + nb_extra_iterations)
     {
       ++it_nb;
@@ -647,6 +663,58 @@ public:
 
 };//end class Adaptive_remesher
 
+
+template<typename Triangulation,
+         typename SizingFunction,
+         typename NamedParameters,
+         typename CornerIndex = int,
+         typename CurveIndex = int>
+struct Adaptive_remesher_type_generator
+{
+  using Tr = Triangulation;
+
+  using Default_Selection_functor = All_cells_selected<Tr>;
+  using SelectionFunctor = typename internal_np::Lookup_named_param_def<
+    internal_np::cell_selector_t,
+    NamedParameters,
+    Default_Selection_functor//default
+  >::type;
+
+  using Vertex_handle = typename Tr::Vertex_handle;
+  using Default_VCMap = Constant_property_map<Vertex_handle, bool>;
+  using VCMap = typename internal_np::Lookup_named_param_def<
+    internal_np::vertex_is_constrained_t,
+    NamedParameters,
+    Default_VCMap//default
+  >::type;
+
+  using Edge_vv = std::pair<Vertex_handle, Vertex_handle>;
+  using Default_ECMap = Constant_property_map<Edge_vv, bool>;
+  using ECMap = typename internal_np::Lookup_named_param_def<
+    internal_np::edge_is_constrained_t,
+    NamedParameters,
+    Default_ECMap//default
+  >::type;
+
+  using Facet = typename Tr::Facet;
+  using Default_FCMap = Constant_property_map<Facet, bool>;
+  using FCMap = typename internal_np::Lookup_named_param_def<
+    internal_np::facet_is_constrained_t,
+    NamedParameters,
+    Default_FCMap//default
+  >::type;
+
+  using Default_Visitor = Default_remeshing_visitor;
+  using Visitor = typename internal_np::Lookup_named_param_def <
+    internal_np::visitor_t,
+    NamedParameters,
+    Default_Visitor//default
+  >::type;
+
+  using type = Adaptive_remesher<
+    Tr, SizingFunction, VCMap, ECMap, FCMap, SelectionFunctor, Visitor>;
+};
+
 }//end namespace internal
 }//end namespace Tetrahedral_remeshing
 }//end namespace CGAL
