@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Three/include/CGAL/Three/Point_container.h $
-// $Id: Point_container.h 97bd67d 2023-06-09T16:26:23+02:00 Laurent Rineau
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Three/include/CGAL/Three/Point_container.h $
+// $Id: include/CGAL/Three/Point_container.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Maxime Gimeno
@@ -65,7 +65,7 @@ struct DEMO_FRAMEWORK_EXPORT Point_container :public Primitive_container
   //!
   //! \param viewer the active `Viewer_interface`.
   //!
-  void initGL(Viewer_interface *viewer)  Q_DECL_OVERRIDE;
+  void initGL(Viewer_interface *viewer)  override;
 
   //!
   //! \brief draw is the function that actually renders the data.
@@ -73,7 +73,7 @@ struct DEMO_FRAMEWORK_EXPORT Point_container :public Primitive_container
   //! \param is_color_uniform must be `false` if `VBOs`[`Colors`] is not empty, `true` otherwise.
   //!
   void draw(CGAL::Three::Viewer_interface* viewer,
-            bool is_color_uniform)  Q_DECL_OVERRIDE;
+            bool is_color_uniform)  override;
 
   /// \name Getters and Setters for the shaders parameters.
   ///
