@@ -4,8 +4,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Triangulation_2/include/CGAL/Triangulation_2/internal/Polyline_constraint_hierarchy_2.h $
-// $Id: Polyline_constraint_hierarchy_2.h e5ce8a7 2023-03-31T11:10:47+02:00 Laurent Rineau
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Triangulation_2/include/CGAL/Triangulation_2/internal/Polyline_constraint_hierarchy_2.h $
+// $Id: include/CGAL/Triangulation_2/internal/Polyline_constraint_hierarchy_2.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -69,7 +69,7 @@ public:
     : public boost::iterator_adaptor<
     Point_it
     , typename Vertex_list::all_iterator
-    , const Point
+    , const Point&
     >
   {
   public:
@@ -86,7 +86,7 @@ public:
     Vertex_it
     , typename Vertex_list::skip_iterator
     , Vertex_handle
-    , boost::use_default
+    , std::bidirectional_iterator_tag
     , Vertex_handle>
   {
   public:
@@ -164,7 +164,7 @@ public:
     Vertex_it    vertices_begin()const { return enclosing->skip_begin();}
     Vertex_it    current()const {return pos;}
     Vertex_it    vertices_end()const {return enclosing->skip_end();}
-    Constraint_id  id() { return enclosing; }
+    Constraint_id  id()const { return enclosing; }
     std::size_t    number_of_vertices() const {return enclosing->skip_size(); }
   };
 
@@ -222,6 +222,7 @@ public:
   std::size_t number_of_enclosing_constraints(T va, T vb) const;
   Context_iterator contexts_begin(T va, T vb) const;
   Context_iterator contexts_end(T va, T vb) const;
+  Iterator_range<Context_iterator> contexts_range(T va, T vb) const;
   std::size_t number_of_constraints() const  { return constraint_set.size();}
   std::size_t number_of_subconstraints()const {return sc_to_c_map.size();}
 
@@ -489,6 +490,15 @@ contexts_end(T va, T vb) const
    return last;
 }
 
+template <class T, class Compare, class Point>
+auto
+Polyline_constraint_hierarchy_2<T,Compare,Point>::
+contexts_range(T va, T vb) const -> Iterator_range<Context_iterator> {
+  Context_iterator first, last;
+  if( !get_contexts(va,vb,first,last)) return { first, first };
+  else return { first, last };
+}
+
 template <class T, class Compare, class Point>
 void
 Polyline_constraint_hierarchy_2<T,Compare,Point>::
@@ -613,7 +623,7 @@ void Polyline_constraint_hierarchy_2<T,Compare,Point>::simplify(Vertex_it uc,
       // Remove the list item which points to v
       Vertex_list* vertex_list = it->id().vl_ptr();
       Vertex_it vc_in_context = it->current();
-      vc_in_context = boost::next(vc_in_context);
+      vc_in_context = std::next(vc_in_context);
       vertex_list->skip(vc_in_context.base());
       ++it;
     }
@@ -626,7 +636,7 @@ void Polyline_constraint_hierarchy_2<T,Compare,Point>::simplify(Vertex_it uc,
       // Remove the list item which points to v
       Vertex_list* vertex_list = it->id().vl_ptr();
       Vertex_it vc_in_context = it->current();
-      vc_in_context = boost::next(vc_in_context);
+      vc_in_context = std::next(vc_in_context);
       vertex_list->skip(vc_in_context.base());
       ++it;
     }
@@ -866,7 +876,7 @@ insert_constraint(T va, T vb){
   using CGAL::IO::oformat;
   Rcpp::Rcerr << CGAL::internal::cdt_2_indent_level
             << "C_hierachy.insert_constraint( "
-            << oformat(va) << ", " << oformat(vb) << ")\n";
+            << IO::oformat(va) << ", " << IO::oformat(vb) << ")\n";
 #endif // CGAL_CDT_2_DEBUG_INTERSECTIONS
   typename Sc_to_c_map::iterator scit = sc_to_c_map.find(he);
   if(scit == sc_to_c_map.end()){
@@ -901,7 +911,7 @@ insert_constraint_old_API(T va, T vb){
   using CGAL::IO::oformat;
   Rcpp::Rcerr << CGAL::internal::cdt_2_indent_level
             << "C_hierachy.insert_constraint_old_API( "
-            << oformat(va) << ", " << oformat(vb) << ")\n";
+            << IO::oformat(va) << ", " << IO::oformat(vb) << ")\n";
 #endif // CGAL_CDT_2_DEBUG_INTERSECTIONS
   typename Sc_to_c_map::iterator scit = sc_to_c_map.find(he);
   if(scit == sc_to_c_map.end()){
@@ -934,7 +944,7 @@ append_constraint(Constraint_id cid, T va, T vb){
   using CGAL::IO::oformat;
   Rcpp::Rcerr << CGAL::internal::cdt_2_indent_level
             << "C_hierachy.append_constraint( ..., "
-            << oformat(va) << ", " << oformat(vb) << ")\n";
+            << IO::oformat(va) << ", " << IO::oformat(vb) << ")\n";
 #endif // CGAL_CDT_2_DEBUG_INTERSECTIONS
   typename Sc_to_c_map::iterator scit = sc_to_c_map.find(he);
   if(scit == sc_to_c_map.end()){
@@ -1051,7 +1061,7 @@ add_Steiner(T va, T vb, T vc){
   using CGAL::IO::oformat;
   Rcpp::Rcerr << CGAL::internal::cdt_2_indent_level
             << "C_hierachy.add_Steinter( "
-            << oformat(va) << ", " << oformat(vb) << ", " << oformat(vc)
+            << IO::oformat(va) << ", " << IO::oformat(vb) << ", " << IO::oformat(vc)
             << ")\n";
 #endif // CGAL_CDT_2_DEBUG_INTERSECTIONS
   Context_list* hcl=nullptr;
