@@ -3,9 +3,9 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Triangulation_2/include/CGAL/Triangulation_2_to_lcc.h $
-// $Id: Triangulation_2_to_lcc.h 999a813 2022-05-05T13:34:19+02:00 Guillaume Damiand
-// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Triangulation_2/include/CGAL/Triangulation_2_to_lcc.h $
+// $Id: include/CGAL/Triangulation_2_to_lcc.h 50cfbde3b84 $
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Guillaume Damiand <guillaume.damiand@liris.cnrs.fr>
 //
@@ -13,6 +13,9 @@
 #ifndef CGAL_TRIANGULATION_2_TO_LCC_H
 #define CGAL_TRIANGULATION_2_TO_LCC_H
 
+#include <CGAL/license/Triangulation_2.h>
+
+
 #include <CGAL/assertions.h>
 #include <map>
 
@@ -31,7 +34,7 @@ namespace CGAL {
    std::map<typename Triangulation::Face_handle,
             typename LCC::Dart_descriptor >* aface_to_dart=nullptr)
   {
-    CGAL_static_assertion( LCC::dimension>=2 && LCC::ambient_dimension==2 );
+    static_assert( LCC::dimension>=2 && LCC::ambient_dimension==2 );
 
     // Case of empty triangulations.
     if (atr.number_of_vertices()==0) return LCC::null_descriptor;
