@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6/Triangulation_3/include/CGAL/Triangulation_3/internal/Triangulation_segment_traverser_3_impl.h $
-// $Id: Triangulation_segment_traverser_3_impl.h 9bbebd4 2023-07-12T15:23:47+02:00 Laurent Rineau
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Triangulation_3/include/CGAL/Triangulation_3/internal/Triangulation_segment_traverser_3_impl.h $
+// $Id: include/CGAL/Triangulation_3/internal/Triangulation_segment_traverser_3_impl.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s): Thijs van Lankveld, Jane Tournois
@@ -505,9 +505,15 @@ Triangulation_segment_cell_iterator_3<Tr,Inc>::walk_to_next_3(const Simplex& pre
         continue;
     }
     const Point* const backup_vert_li = std::exchange(vert[li], &_target);
-
+    bool op_li_is_null = false;
+    if(_t_vertex != Vertex_handle()) {
+      for(int i = 0; i < 4; ++i) {
+        if(li == i) continue;
+        if(cur_cell->vertex(i) == _t_vertex) op_li_is_null = true;
+      }
+    }
     // Check if the target is on the opposite side of the supporting plane.
-    op[li] = _tr->orientation(*vert[0], *vert[1], *vert[2], *vert[3]);
+    op[li] = op_li_is_null ? ZERO : _tr->orientation(*vert[0], *vert[1], *vert[2], *vert[3]);
     if(op[li] == POSITIVE)
         pos += li;
     if(op[li] != NEGATIVE) {
@@ -597,7 +603,7 @@ Triangulation_segment_cell_iterator_3<Tr,Inc>::walk_to_next_3(const Simplex& pre
   // The target lies inside this cell.
   CGAL_assertion( incell );
   return {
-    [&]() -> Simplex {
+    std::invoke([&]() -> Simplex {
       switch( op[0] + op[1] + op[2] + op[3] ) {
       case 4:
         CGAL_assertion( pos == 6 );
@@ -625,7 +631,7 @@ Triangulation_segment_cell_iterator_3<Tr,Inc>::walk_to_next_3(const Simplex& pre
       default:
         CGAL_unreachable();
       }
-    }(),
+    }),
     { Cell_handle() }
   };
 }
@@ -748,7 +754,7 @@ template < class Tr, class Inc >
 void Triangulation_segment_cell_iterator_3<Tr,Inc>::
 walk_to_next_2()
 {
-    std::array<Point*, 3> vert
+    const std::array<const Point*, 3> vert
               = { &(cell()->vertex(0)->point()),
                   &(cell()->vertex(1)->point()),
                   &(cell()->vertex(2)->point()) };
