@@ -8,8 +8,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/STL_Extension/include/CGAL/algorithm.h $
-// $Id: algorithm.h 4e519a3 2021-05-05T13:15:37+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/STL_Extension/include/CGAL/algorithm.h $
+// $Id: include/CGAL/algorithm.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -264,7 +264,7 @@ lexicographical_compare_three_valued( InputIterator1 first1, InputIterator1 last
     The iterator range \c [first,beyond) is written
     to \c os (obeying CGAL I/O modes). Each element is bracketed by
     \c pre and \c post (default: empty string). Adjacent values are
-    spearated by \c sep (default: ", ", i.e. comma space).
+    separated by \c sep (default: ", ", i.e. comma space).
     The stream \c os is returned in its new state after output.
 
     Example:
