@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/BGL/include/CGAL/boost/graph/METIS/partition_dual_graph.h $
-// $Id: partition_dual_graph.h 75b03e6 2022-01-10T15:33:04+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/BGL/include/CGAL/boost/graph/METIS/partition_dual_graph.h $
+// $Id: include/CGAL/boost/graph/METIS/partition_dual_graph.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Mael Rouxel-Labbé
@@ -33,6 +33,8 @@ namespace CGAL {
 
 namespace METIS {
 
+#ifndef DOXYGEN_RUNNING
+
 template<typename TriangleMesh, typename METIS_options, typename NamedParameters>
 void partition_dual_graph(const TriangleMesh& tm,
                           int nparts,
@@ -114,8 +116,8 @@ void partition_dual_graph(const TriangleMesh& tm,
   delete[] eptr;
   delete[] eind;
 
-  std::free(npart);
-  std::free(epart);
+  (std::free)(npart);
+  (std::free)(epart);
 }
 
 template<typename TriangleMesh, typename NamedParameters>
@@ -128,6 +130,8 @@ void partition_dual_graph(const TriangleMesh& tm, int nparts,
   return partition_dual_graph(tm, nparts, &options, np);
 }
 
+#endif
+
 /// \ingroup PkgBGLPartition
 ///
 /// computes a partition of the input triangular mesh into `nparts` parts,
