@@ -2,9 +2,9 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Surface_mesh/include/CGAL/boost/graph/properties_Surface_mesh.h $
-// $Id: properties_Surface_mesh.h 590ddf8 2021-10-08T15:38:47+02:00 Mael Rouxel-Labbé
-// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Surface_mesh/include/CGAL/boost/graph/properties_Surface_mesh.h $
+// $Id: include/CGAL/boost/graph/properties_Surface_mesh.h 50cfbde3b84 $
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
 // Author(s)     : Philipp Möller
@@ -43,7 +43,7 @@ public:
   SM_edge_weight_pmap(const CGAL::Surface_mesh<Point>& sm)
     : pm_(sm. template property_map<
             typename SM::Vertex_index,
-            typename SM::Point >("v:point").first),
+            typename SM::Point >("v:point").value()),
       sm_(sm)
     {}
 
@@ -71,8 +71,8 @@ class SM_index_pmap
 {
 public:
   typedef boost::readable_property_map_tag category;
-  typedef boost::uint32_t                  value_type;
-  typedef boost::uint32_t                  reference;
+  typedef std::uint32_t                  value_type;
+  typedef std::uint32_t                  reference;
   typedef VEF                              key_type;
 
   value_type operator[](const key_type& vd) const
@@ -238,7 +238,7 @@ template<typename Point>
 typename
 boost::lazy_disable_if
 <
-  boost::is_const<Point>,
+  std::is_const<Point>,
   internal::Get_vertex_point_map_for_Surface_mesh_return_type<Point>
 >::type
 get(CGAL::vertex_point_t, const CGAL::Surface_mesh<Point>& g) {
@@ -260,13 +260,13 @@ namespace internal {
      const TYPE& x)                                                \
  { return get(get(p, sm), x); }                                        \
 
-CGAL_SM_INTRINSIC_PROPERTY(boost::uint32_t, boost::vertex_index_t,
+CGAL_SM_INTRINSIC_PROPERTY(std::uint32_t, boost::vertex_index_t,
 SM_Vertex_index)
-CGAL_SM_INTRINSIC_PROPERTY(boost::uint32_t, boost::edge_index_t,
+CGAL_SM_INTRINSIC_PROPERTY(std::uint32_t, boost::edge_index_t,
 SM_Edge_index)
-CGAL_SM_INTRINSIC_PROPERTY(boost::uint32_t, boost::halfedge_index_t,
+CGAL_SM_INTRINSIC_PROPERTY(std::uint32_t, boost::halfedge_index_t,
 SM_Halfedge_index)
-CGAL_SM_INTRINSIC_PROPERTY(boost::uint32_t, boost::face_index_t,
+CGAL_SM_INTRINSIC_PROPERTY(std::uint32_t, boost::face_index_t,
 SM_Face_index)
 CGAL_SM_INTRINSIC_PROPERTY(Point&, CGAL::vertex_point_t, SM_Vertex_index)
 
@@ -353,67 +353,67 @@ namespace CGAL {
 // get functions for dynamic properties of mutable Surface_mesh
 template <typename Point, typename T>
 typename boost::property_map<CGAL::Surface_mesh<Point>, dynamic_vertex_property_t<T> >::type
-get(dynamic_vertex_property_t<T>, Surface_mesh<Point>& sm)
+get(dynamic_vertex_property_t<T>, Surface_mesh<Point>& sm, const T& default_value = T())
 {
   typedef typename boost::property_map<Surface_mesh<Point>, dynamic_vertex_property_t<T> >::SMPM SMPM;
   typedef typename boost::property_map<Surface_mesh<Point>, dynamic_vertex_property_t<T> >::type DPM;
-  return DPM(sm, new SMPM(sm.template add_property_map<typename Surface_mesh<Point>::Vertex_index, T>(std::string()).first));
+  return DPM(sm, new SMPM(sm.template add_property_map<typename Surface_mesh<Point>::Vertex_index, T>(std::string(), default_value).first));
 }
 
 template <typename Point, typename T>
 typename boost::property_map<Surface_mesh<Point>, dynamic_face_property_t<T> >::type
-get(dynamic_face_property_t<T>, Surface_mesh<Point>& sm)
+get(dynamic_face_property_t<T>, Surface_mesh<Point>& sm, const T& default_value = T())
 {
   typedef typename boost::property_map<Surface_mesh<Point>, dynamic_face_property_t<T> >::SMPM SMPM;
   typedef typename boost::property_map<Surface_mesh<Point>, dynamic_face_property_t<T> >::type DPM;
-  return DPM(sm, new SMPM(sm.template add_property_map<typename Surface_mesh<Point>::Face_index, T>(std::string()).first));
+  return DPM(sm, new SMPM(sm.template add_property_map<typename Surface_mesh<Point>::Face_index, T>(std::string(), default_value).first));
 }
 
 template <typename Point, typename T>
 typename boost::property_map<Surface_mesh<Point>, dynamic_edge_property_t<T> >::type
-get(dynamic_edge_property_t<T>, Surface_mesh<Point>& sm)
+get(dynamic_edge_property_t<T>, Surface_mesh<Point>& sm, const T& default_value = T())
 {
   typedef typename boost::property_map<Surface_mesh<Point>, dynamic_edge_property_t<T> >::SMPM SMPM;
   typedef typename boost::property_map<Surface_mesh<Point>, dynamic_edge_property_t<T> >::type DPM;
-  return DPM(sm, new SMPM(sm.template add_property_map<typename Surface_mesh<Point>::Edge_index, T>(std::string()).first));
+  return DPM(sm, new SMPM(sm.template add_property_map<typename Surface_mesh<Point>::Edge_index, T>(std::string(), default_value).first));
 }
 
 template <typename Point, typename T>
 typename boost::property_map<Surface_mesh<Point>, dynamic_halfedge_property_t<T> >::type
-get(dynamic_halfedge_property_t<T>, Surface_mesh<Point>& sm)
+get(dynamic_halfedge_property_t<T>, Surface_mesh<Point>& sm, const T& default_value = T())
 {
   typedef typename boost::property_map<Surface_mesh<Point>, dynamic_halfedge_property_t<T> >::SMPM SMPM;
   typedef typename boost::property_map<Surface_mesh<Point>, dynamic_halfedge_property_t<T> >::type DPM;
-  return DPM(sm, new SMPM(sm.template add_property_map<typename Surface_mesh<Point>::Halfedge_index, T>(std::string()).first));
+  return DPM(sm, new SMPM(sm.template add_property_map<typename Surface_mesh<Point>::Halfedge_index, T>(std::string(), default_value).first));
 }
 
 // get functions for dynamic properties of const Surface_mesh
 template <typename Point, typename T>
 typename boost::property_map<Surface_mesh<Point>, dynamic_vertex_property_t<T> >::const_type
-get(dynamic_vertex_property_t<T>, const Surface_mesh<Point>& sm)
+get(dynamic_vertex_property_t<T>, const Surface_mesh<Point>& sm, const T& default_value = T())
 {
-  return CGAL::internal::Dynamic_with_index<typename Surface_mesh<Point>::Vertex_index, T>(num_vertices(sm));
+  return CGAL::internal::Dynamic_with_index<typename Surface_mesh<Point>::Vertex_index, T>(num_vertices(sm), default_value);
 }
 
 template <typename Point, typename T>
 typename boost::property_map<Surface_mesh<Point>, dynamic_face_property_t<T> >::const_type
-get(dynamic_face_property_t<T>, const Surface_mesh<Point>& sm)
+get(dynamic_face_property_t<T>, const Surface_mesh<Point>& sm, const T& default_value = T())
 {
-  return CGAL::internal::Dynamic_with_index<typename Surface_mesh<Point>::Face_index, T>(num_faces(sm));
+  return CGAL::internal::Dynamic_with_index<typename Surface_mesh<Point>::Face_index, T>(num_faces(sm), default_value);
 }
 
 template <typename Point, typename T>
 typename boost::property_map<Surface_mesh<Point>, dynamic_halfedge_property_t<T> >::const_type
-get(dynamic_halfedge_property_t<T>, const Surface_mesh<Point>& sm)
+get(dynamic_halfedge_property_t<T>, const Surface_mesh<Point>& sm, const T& default_value = T())
 {
-  return CGAL::internal::Dynamic_with_index<typename Surface_mesh<Point>::Halfedge_index, T>(num_halfedges(sm));
+  return CGAL::internal::Dynamic_with_index<typename Surface_mesh<Point>::Halfedge_index, T>(num_halfedges(sm), default_value);
 }
 
 template <typename Point, typename T>
 typename boost::property_map<Surface_mesh<Point>, dynamic_edge_property_t<T> >::const_type
-get(dynamic_edge_property_t<T>, const Surface_mesh<Point>& sm)
+get(dynamic_edge_property_t<T>, const Surface_mesh<Point>& sm, const T& default_value = T())
 {
-  return CGAL::internal::Dynamic_with_index<typename Surface_mesh<Point>::Edge_index, T>(num_edges(sm));
+  return CGAL::internal::Dynamic_with_index<typename Surface_mesh<Point>::Edge_index, T>(num_edges(sm), default_value);
 }
 
 // implementation detail: required by Dynamic_property_map_deleter
