@@ -3,64 +3,85 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Polyhedron/include/CGAL/draw_polyhedron.h $
-// $Id: draw_polyhedron.h 2bbcabe 2021-11-11T17:23:37+01:00 Guillaume Damiand
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Polyhedron/include/CGAL/draw_polyhedron.h $
+// $Id: include/CGAL/draw_polyhedron.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Guillaume Damiand <guillaume.damiand@liris.cnrs.fr>
+//                 Mostafa Ashraf <mostaphaashraf1996@gmail.com>
 
 #ifndef CGAL_DRAW_POLYHEDRON_H
 #define CGAL_DRAW_POLYHEDRON_H
 
 #include <CGAL/license/Polyhedron.h>
-#include <CGAL/Qt/Basic_viewer_qt.h>
-
-#ifdef CGAL_USE_BASIC_VIEWER
-#include <CGAL/Qt/init_ogl_context.h>
+#include <CGAL/Graphics_scene.h>
+#include <CGAL/Graphics_scene_options.h>
 #include <CGAL/Polyhedron_3.h>
 #include <CGAL/draw_face_graph.h>
-#include <CGAL/Random.h>
+#include <CGAL/Qt/Basic_viewer.h>
 
 namespace CGAL
 {
 
-// Specialization of draw function.
 #define CGAL_POLY_TYPE CGAL::Polyhedron_3 \
   <PolyhedronTraits_3, PolyhedronItems_3, T_HDS, Alloc>
 
+// Specialization of add_to_graphics_scene function.
+template<class PolyhedronTraits_3,
+         class PolyhedronItems_3,
+         template < class T, class I, class A>
+         class T_HDS,
+         class Alloc,
+         class GSOptions>
+void add_to_graphics_scene(const CGAL_POLY_TYPE& apoly,
+                           CGAL::Graphics_scene &graphics_scene,
+                           const GSOptions &gs_options)
+{ add_to_graphics_scene_for_fg(apoly, graphics_scene, gs_options); }
+
+template<class PolyhedronTraits_3,
+         class PolyhedronItems_3,
+         template < class T, class I, class A>
+         class T_HDS,
+         class Alloc>
+void add_to_graphics_scene(const CGAL_POLY_TYPE& apoly,
+                           CGAL::Graphics_scene &graphics_scene)
+{ add_to_graphics_scene_for_fg(apoly, graphics_scene); }
+
+// Specialization of draw function: require Qt and the CGAL basic viewer.
+#ifdef CGAL_USE_BASIC_VIEWER
+
 template<class PolyhedronTraits_3,
          class PolyhedronItems_3,
          template < class T, class I, class A>
          class T_HDS,
          class Alloc>
 void draw(const CGAL_POLY_TYPE& apoly,
-          const char* title="Polyhedron Basic Viewer",
-          bool nofill=false)
+          const char* title="Polyhedron Basic Viewer")
 {
-#if defined(CGAL_TEST_SUITE)
-  bool cgal_test_suite=true;
-#else
-  bool cgal_test_suite=qEnvironmentVariableIsSet("CGAL_TEST_SUITE");
-#endif
-
-  if (!cgal_test_suite)
-  {
-    CGAL::Qt::init_ogl_context(4,3);
-    int argc=1;
-    const char* argv[2]={"polyhedron_viewer", nullptr};
-    QApplication app(argc,const_cast<char**>(argv));
-    SimpleFaceGraphViewerQt
-      mainwindow(app.activeWindow(), apoly, title, nofill);
-    mainwindow.show();
-    app.exec();
-  }
+  CGAL::Graphics_scene buffer;
+  add_to_graphics_scene_for_fg(apoly, buffer);
+  draw_graphics_scene(buffer, title);
 }
 
+template<class PolyhedronTraits_3,
+         class PolyhedronItems_3,
+         template < class T, class I, class A>
+         class T_HDS,
+         class Alloc,
+         class GSOptions>
+void draw(const CGAL_POLY_TYPE& apoly,
+          const GSOptions &gs_options,
+          const char* title="Polyhedron Basic Viewer")
+{
+  CGAL::Graphics_scene buffer;
+  add_to_graphics_scene_for_fg(apoly, buffer, gs_options);
+  draw_graphics_scene(buffer, title);
+}
+#endif // CGAL_USE_BASIC_VIEWER
+
 #undef CGAL_POLY_TYPE
 
 } // End namespace CGAL
 
-#endif // CGAL_USE_BASIC_VIEWER
-
 #endif // CGAL_DRAW_POLYHEDRON_H
 
